"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.editSchema = exports.getFilter = exports.createFilter = exports.operators = void 0;
var get_1 = __importDefault(require("lodash/get"));
var SchemaSieve_1 = require("../Filters/SchemaSieve");
var _1 = require(".");
var operators = function () { return ({
    contains: 'contains',
    not_contains: 'does not contain',
}); };
exports.operators = operators;
var isSchemaWithPrimitiveItems = function (schema) {
    return !!(schema === null || schema === void 0 ? void 0 : schema.items) &&
        typeof schema.items !== 'boolean' &&
        'type' in schema.items;
};
var createFilter = function (field, operator, value, schema, _refScheme) {
    var _a;
    var filter = (0, exports.getFilter)(field, schema, value, operator);
    if (!Object.keys(filter).length) {
        return {};
    }
    return {
        properties: (_a = {},
            _a[field] = __assign({ type: 'array' }, filter),
            _a),
        required: [field],
    };
};
exports.createFilter = createFilter;
var getFilter = function (field, schema, value, operator) {
    var _a;
    if (!!(schema === null || schema === void 0 ? void 0 : schema.items) &&
        typeof schema.items !== 'boolean' &&
        'properties' in schema.items &&
        !!schema.items.properties) {
        var propertyFilters = Object.entries(schema.items.properties).map(function (_a) {
            var propKey = _a[0], propSchema = _a[1];
            return (0, SchemaSieve_1.getModelFilter)(propSchema, propKey, operator, value);
        });
        return {
            minItems: 1,
            contains: propertyFilters.length === 1
                ? propertyFilters[0]
                : {
                    anyOf: propertyFilters,
                },
        };
    }
    var hasPrimitiveItems = isSchemaWithPrimitiveItems(schema);
    var filterSchema = hasPrimitiveItems ? schema.items : schema;
    var innerOperator = operator.slug === SchemaSieve_1.FULL_TEXT_SLUG ||
        (hasPrimitiveItems && schema.items.type === 'string')
        ? operator
        : convertOperatorToIs(operator);
    var filter = (0, SchemaSieve_1.getModelFilter)(filterSchema, field, innerOperator, value);
    var recursiveFilter = (_a = filter.properties) === null || _a === void 0 ? void 0 : _a[field];
    var targetFilter = hasPrimitiveItems && recursiveFilter ? recursiveFilter : filter;
    if (!Object.keys(targetFilter).length) {
        return targetFilter;
    }
    if (typeof targetFilter.not === 'object') {
        return {
            not: { contains: targetFilter.not },
        };
    }
    return { minItems: 1, contains: targetFilter };
};
exports.getFilter = getFilter;
var convertOperatorToIs = function (operator) {
    if (operator.slug === 'not_contains') {
        return { slug: 'is_not', label: 'is not' };
    }
    if (operator.slug === 'contains') {
        return { slug: 'is', label: 'is' };
    }
    return operator;
};
var editSchema = function (schema, operator) {
    var refScheme = (0, SchemaSieve_1.getPropertyScheme)(schema);
    var schemaItems = schema.items;
    var convertedRefScheme = (0, SchemaSieve_1.convertRefSchemeToSchemaPath)(refScheme === null || refScheme === void 0 ? void 0 : refScheme[0]);
    if (!!schemaItems && !!convertedRefScheme) {
        var property = (0, get_1.default)(schemaItems.properties, convertedRefScheme);
        return property;
    }
    var subSchema = schemaItems || schema;
    var model = (0, _1.getDataModel)(subSchema);
    return model && 'editSchema' in model
        ? model.editSchema(subSchema, operator)
        : subSchema;
};
exports.editSchema = editSchema;
