"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFilter = exports.uiSchema = exports.editSchema = exports.createFilter = exports.operators = exports.isKeyValueObj = void 0;
var find_1 = __importDefault(require("lodash/find"));
var findKey_1 = __importDefault(require("lodash/findKey"));
var mapValues_1 = __importDefault(require("lodash/mapValues"));
var pick_1 = __importDefault(require("lodash/pick"));
var utils_1 = require("../../utils");
var SchemaSieve_1 = require("../Filters/SchemaSieve");
var getKeyLabel = function (schema) {
    var s = (0, find_1.default)(schema.properties, { description: 'key' });
    return s && s.title ? s.title : 'key';
};
var getValueLabel = function (schema) {
    var s = (0, find_1.default)(schema.properties, { description: 'value' });
    return s && s.title ? s.title : 'value';
};
var isKeyValueObj = function (schema) {
    return !!(0, find_1.default)(schema.properties, { description: 'key' }) ||
        !!(0, find_1.default)(schema.properties, { description: 'value' });
};
exports.isKeyValueObj = isKeyValueObj;
var operators = function (s) {
    return __assign(__assign({}, (!(0, SchemaSieve_1.getPropertyScheme)(s)
        ? {
            is: 'is',
            is_not: 'is not',
        }
        : {})), (!(0, exports.isKeyValueObj)(s)
        ? {
            contains: 'contains',
            not_contains: 'does not contain',
        }
        : (function () {
            var keyLabel = getKeyLabel(s);
            var valueLabel = getValueLabel(s);
            return {
                key_contains: "".concat(keyLabel, " contains"),
                key_not_contains: "".concat(keyLabel, " does not contain"),
                key_is: "".concat(keyLabel, " is"),
                key_matches_re: "".concat(keyLabel, " matches RegEx"),
                key_not_matches_re: "".concat(keyLabel, " does not match RegEx"),
                value_is: "".concat(valueLabel, " is"),
                value_contains: "".concat(valueLabel, " contains"),
                value_not_contains: "".concat(valueLabel, " does not contain"),
                value_matches_re: "".concat(valueLabel, " matches RegEx"),
                value_not_matches_re: "".concat(valueLabel, " does not match RegEx"),
            };
        })()));
};
exports.operators = operators;
var keySpecificOperators = [
    'key_is',
    'key_contains',
    'key_not_contains',
    'key_matches_re',
    'key_not_matches_re',
];
var valueSpecificOperators = [
    'value_is',
    'value_contains',
    'value_not_contains',
    'value_matches_re',
    'value_not_matches_re',
];
function getValueForOperation(operator, schema, value) {
    var _a, _b;
    if (keySpecificOperators.includes(operator)) {
        var schemaKey = (0, findKey_1.default)(schema.properties, { description: 'key' });
        return typeof value === 'string'
            ? (_a = {}, _a[schemaKey] = value, _a) : (0, pick_1.default)(value, schemaKey);
    }
    if (valueSpecificOperators.includes(operator)) {
        var schemaValue = (0, findKey_1.default)(schema.properties, { description: 'value' });
        return typeof value === 'string'
            ? (_b = {}, _b[schemaValue] = value, _b) : (0, pick_1.default)(value, schemaValue);
    }
    return value;
}
var getTitleForOperation = function (operator, schema, value) {
    if (typeof value !== 'object' || !schema.properties) {
        return schema.title;
    }
    var property = schema.properties[Object.keys(value)[0]];
    if (__spreadArray(__spreadArray([], keySpecificOperators, true), valueSpecificOperators, true).includes(operator) &&
        typeof property === 'object') {
        return property.title;
    }
    return schema.title;
};
var createFilter = function (field, operator, value, schema) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j;
    var operatorSlug = operator.slug;
    value = !!(0, exports.isKeyValueObj)(schema)
        ? getValueForOperation(operatorSlug, schema, value)
        : value;
    var propertyTitle = getTitleForOperation(operatorSlug, schema, value);
    var isFilter = function (v) { return ({ const: v }); };
    var containsFilter = function (v) { return ({
        description: v,
        regexp: {
            pattern: (0, utils_1.regexEscape)(v),
            flags: 'i',
        },
    }); };
    var matchReGexFilter = function (v) { return ({
        pattern: v,
    }); };
    if (!(0, exports.isKeyValueObj)(schema)) {
        return {
            properties: (_a = {},
                _a[field] = (0, exports.getFilter)(field, schema, value, operator),
                _a),
            required: [field],
        };
    }
    if (operatorSlug === SchemaSieve_1.FULL_TEXT_SLUG) {
        var schemaKey = (0, findKey_1.default)(schema.properties, { description: 'key' });
        var schemaValue = (0, findKey_1.default)(schema.properties, { description: 'value' });
        var properties = [schemaKey, schemaValue].map(function (key) {
            var _a;
            return ({
                properties: (_a = {},
                    _a[key] = {
                        pattern: value,
                    },
                    _a),
                required: [key],
            });
        });
        return {
            properties: (_b = {},
                _b[field] = {
                    contains: {
                        title: propertyTitle,
                        anyOf: properties,
                    },
                },
                _b),
        };
    }
    if (operatorSlug === 'is') {
        return {
            properties: (_c = {},
                _c[field] = {
                    contains: {
                        title: propertyTitle,
                        properties: (0, mapValues_1.default)(value, function (v) { return ({ const: v }); }),
                    },
                },
                _c),
            required: [field],
        };
    }
    if (operatorSlug === 'is_not') {
        return {
            properties: (_d = {},
                _d[field] = {
                    not: {
                        contains: {
                            title: propertyTitle,
                            properties: (0, mapValues_1.default)(value, function (v) { return ({ const: v }); }),
                        },
                    },
                },
                _d),
        };
    }
    if (operatorSlug === 'key_is' || operatorSlug === 'value_is') {
        return {
            properties: (_e = {},
                _e[field] = {
                    contains: {
                        title: propertyTitle,
                        properties: (0, mapValues_1.default)(value, isFilter),
                    },
                },
                _e),
            required: [field],
        };
    }
    if (operatorSlug === 'key_contains' || operatorSlug === 'value_contains') {
        return {
            properties: (_f = {},
                _f[field] = {
                    contains: {
                        title: propertyTitle,
                        properties: typeof value !== 'object'
                            ? containsFilter(value)
                            : (0, mapValues_1.default)(value, containsFilter),
                    },
                },
                _f),
            required: [field],
        };
    }
    if (operatorSlug === 'key_not_contains' ||
        operatorSlug === 'value_not_contains') {
        return {
            properties: (_g = {},
                _g[field] = {
                    not: {
                        contains: {
                            title: propertyTitle,
                            properties: typeof value !== 'object'
                                ? containsFilter(value)
                                : (0, mapValues_1.default)(value, containsFilter),
                        },
                    },
                },
                _g),
        };
    }
    if (operatorSlug === 'key_matches_re' ||
        operatorSlug === 'value_matches_re') {
        return {
            properties: (_h = {},
                _h[field] = {
                    contains: {
                        title: propertyTitle,
                        properties: typeof value !== 'object'
                            ? matchReGexFilter(value)
                            : (0, mapValues_1.default)(value, matchReGexFilter),
                    },
                },
                _h),
            required: [field],
        };
    }
    if (operatorSlug === 'key_not_matches_re' ||
        operatorSlug === 'value_not_matches_re') {
        return {
            properties: (_j = {},
                _j[field] = {
                    not: {
                        contains: {
                            title: propertyTitle,
                            properties: typeof value !== 'object'
                                ? matchReGexFilter(value)
                                : (0, mapValues_1.default)(value, matchReGexFilter),
                        },
                    },
                },
                _j),
        };
    }
    return {};
};
exports.createFilter = createFilter;
var editSchema = function (schema, operator) {
    var schemaKey = (0, findKey_1.default)(schema.properties, { description: 'key' });
    var schemaValue = (0, findKey_1.default)(schema.properties, { description: 'value' });
    if (!!operator &&
        keySpecificOperators.includes(operator.slug) &&
        !!schemaKey) {
        return __assign(__assign({}, schema), { title: '', properties: (0, pick_1.default)(schema.properties, schemaKey) });
    }
    if (!!operator &&
        valueSpecificOperators.includes(operator.slug) &&
        !!schemaValue) {
        return __assign(__assign({}, schema), { title: '', properties: (0, pick_1.default)(schema.properties, schemaValue) });
    }
    return __assign(__assign({}, schema), { title: '' });
};
exports.editSchema = editSchema;
var uiSchema = function (schema) {
    var _a, _b;
    if (!schema.properties || typeof schema.properties !== 'object') {
        return {};
    }
    return ((_b = (_a = Object.entries(schema.properties)) === null || _a === void 0 ? void 0 : _a.reduce(function (acc, _a) {
        var key = _a[0], value = _a[1];
        acc[key] = {
            'ui:options': {
                label: false,
                placeholder: typeof value.title === 'string' ? value.title : '',
            },
        };
        return acc;
    }, {})) !== null && _b !== void 0 ? _b : {});
};
exports.uiSchema = uiSchema;
var getFilter = function (field, schema, value, operator) {
    var _a;
    if (!!(schema === null || schema === void 0 ? void 0 : schema.properties) && typeof schema.properties !== 'boolean') {
        return {
            anyOf: Object.entries(schema.properties).map(function (_a) {
                var propKey = _a[0], propValue = _a[1];
                var filter = (0, SchemaSieve_1.getModelFilter)(propValue, propKey, operator, value);
                return filter;
            }),
        };
    }
    var fieldFilter = (0, SchemaSieve_1.getModelFilter)(schema, field, operator, value);
    return {
        contains: (_a = fieldFilter.properties) === null || _a === void 0 ? void 0 : _a[field],
    };
};
exports.getFilter = getFilter;
