"use strict";
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
Object.defineProperty(exports, "__esModule", { value: true });
var DataTypes_1 = require("../../components/DataTypes");
var date_time_helpers_1 = require("../../components/DataTypes/date-time-helpers");
var expectMatchesKeys = function (data, keys) {
    return expect(Object.keys(data).sort()).toEqual(keys.sort());
};
describe('DataTypes', function () {
    describe('.getDataModel()', function () {
        var dataModelKeys = ['operators', 'createFilter'];
        it('should return null if provided with a falsey value as the schema parameter', function () {
            expect((0, DataTypes_1.getDataModel)()).toBe(null);
            expect((0, DataTypes_1.getDataModel)(undefined)).toBe(null);
            expect((0, DataTypes_1.getDataModel)(0)).toBe(null);
            expect((0, DataTypes_1.getDataModel)(false)).toBe(null);
            expect((0, DataTypes_1.getDataModel)(null)).toBe(null);
            expect((0, DataTypes_1.getDataModel)('')).toBe(null);
        });
        it('should return null for unknown types', function () {
            var schema = {
                type: 'foobar',
            };
            expect((0, DataTypes_1.getDataModel)(schema)).toBe(null);
        });
        it('should return a model for string types', function () {
            var schema = {
                type: 'string',
            };
            expectMatchesKeys((0, DataTypes_1.getDataModel)(schema), dataModelKeys);
        });
        it('should return a model for string | null types', function () {
            var schema = {
                type: ['string', 'null'],
            };
            expectMatchesKeys((0, DataTypes_1.getDataModel)(schema), dataModelKeys);
        });
        it('should return a model for date-time formatted string types', function () {
            var schema = {
                type: 'string',
                format: 'date-time',
            };
            expectMatchesKeys((0, DataTypes_1.getDataModel)(schema), dataModelKeys);
        });
        it('should return a model for object types', function () {
            var schema = {
                type: 'object',
            };
            expectMatchesKeys((0, DataTypes_1.getDataModel)(schema), __spreadArray([
                'editSchema',
                'getFilter',
                'isKeyValueObj',
                'uiSchema'
            ], dataModelKeys, true));
        });
        it('should return a model for boolean types', function () {
            var schema = {
                type: 'boolean',
            };
            expectMatchesKeys((0, DataTypes_1.getDataModel)(schema), __spreadArray(__spreadArray([], dataModelKeys, true), ['uiSchema'], false));
        });
        it('should return a model for number types', function () {
            var schema = {
                type: 'number',
            };
            expectMatchesKeys((0, DataTypes_1.getDataModel)(schema), dataModelKeys);
        });
    });
    describe('normalizeDateTime', function () {
        it('rejects invalid date', function () {
            expect((0, date_time_helpers_1.normalizeDateTime)('wrong time')).toEqual(null);
            expect((0, date_time_helpers_1.normalizeDateTime)('')).toEqual(null);
        });
        it('formats the date correctly', function () {
            var tzFormat = function (stamp) {
                return new Date(stamp).toISOString().replace(/\.000/, '');
            };
            expect((0, date_time_helpers_1.normalizeDateTime)('2017-01-01T08:49:26Z')).toEqual(tzFormat('2017-01-01T08:49:26Z'));
            expect((0, date_time_helpers_1.normalizeDateTime)('2018-03-26T11:43')).toEqual(tzFormat('2018-03-26T11:43'));
            expect((0, date_time_helpers_1.normalizeDateTime)('Sun, 01 Jan 2017 08:49:26 +0000')).toEqual(tzFormat('2017-01-01T08:49:26Z'));
        });
    });
});
