"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FilterModal = void 0;
var react_1 = __importDefault(require("react"));
var Flex_1 = require("../Flex");
var Modal_1 = require("../Modal");
var Select_1 = require("../Select");
var debounce_1 = __importDefault(require("lodash/debounce"));
var SchemaSieve_1 = require("./SchemaSieve");
var Txt_1 = require("../Txt");
var DataTypes_1 = require("../DataTypes");
var Form_1 = require("../Form");
var SchemaSieve_2 = require("./SchemaSieve");
var Button_1 = require("../Button");
var react_fontawesome_1 = require("@fortawesome/react-fontawesome");
var faTimes_1 = require("@fortawesome/free-solid-svg-icons/faTimes");
var utils_1 = require("../../utils");
var FilterModal = function (_a) {
    var schema = _a.schema, editFilter = _a.editFilter, addFilter = _a.addFilter, onClose = _a.onClose;
    var properties = react_1.default.useMemo(function () {
        if (!schema.properties || typeof schema.properties === 'boolean') {
            return;
        }
        var constructedProperties = Object.entries(schema.properties).flatMap(function (_a) {
            var key = _a[0], value = _a[1];
            var refScheme = (0, SchemaSieve_2.getPropertyScheme)(value);
            if (!(refScheme === null || refScheme === void 0 ? void 0 : refScheme.length)) {
                return {
                    key: key,
                    field: key,
                    title: (0, SchemaSieve_2.getSchemaTitle)(value, key),
                };
            }
            else {
                return refScheme.map(function (ref) {
                    return {
                        key: "".concat(key, "__").concat(ref),
                        field: key,
                        title: (0, SchemaSieve_2.getSchemaTitle)(value, key, ref),
                        refScheme: ref,
                    };
                });
            }
        });
        return constructedProperties.sort(function (a, b) { return (a.title > b.title ? 1 : -1); });
    }, [schema]);
    var newSignature = properties
        ? {
            key: properties[0].refScheme
                ? "".concat(properties[0].field, "__").concat(properties[0].refScheme)
                : properties[0].field,
            title: properties[0].title,
            field: properties[0].field,
            operator: undefined,
            value: undefined,
            label: undefined,
            refScheme: properties[0].refScheme,
        }
        : null;
    var _b = react_1.default.useState(editFilter ? (0, SchemaSieve_1.getSignatures)(editFilter) : newSignature ? [newSignature] : []), signatures = _b[0], setSignatures = _b[1];
    if (!properties || !newSignature) {
        return null;
    }
    var addSignature = function (signature, index) {
        if (!signatures) {
            return;
        }
        if (!signatures.length) {
            setSignatures([__assign({}, signature)]);
        }
        else if (signatures.length >= index + 1) {
            signatures[index] = __assign({}, signature);
            setSignatures(__spreadArray([], signatures, true));
        }
        else {
            setSignatures(__spreadArray(__spreadArray([], signatures, true), [__assign({}, signature)], false));
        }
    };
    var removeSignature = function (index) {
        var newSignatures = signatures.filter(function (_f, i) { return index !== i; });
        setSignatures(newSignatures);
    };
    var isValid = function (signs) {
        return signs.every(function (s) { return s.field && s.operator && s.value != null && s.value !== ''; });
    };
    var createAndAddFilter = function () {
        if (!isValid(signatures)) {
            return;
        }
        var filter = (0, SchemaSieve_1.createFilter)(schema, signatures);
        return filter ? addFilter(filter) : onClose();
    };
    return (react_1.default.createElement(Modal_1.Modal, { title: "Filter by", cancel: onClose, done: createAndAddFilter, primaryButtonProps: {
            disabled: !isValid(signatures),
        }, action: "Save" },
        signatures.map(function (signature, index) { return (react_1.default.createElement(Flex_1.Flex, { flexDirection: "column", key: (signature.field || '') + index },
            index > 0 && react_1.default.createElement(Txt_1.Txt, { my: 2 }, "OR"),
            react_1.default.createElement(Flex_1.Flex, null,
                react_1.default.createElement(FilterInputs, { properties: properties, signature: signature, schema: schema, onUpdate: function (signature) { return addSignature(signature, index); } }),
                index > 0 && (react_1.default.createElement(Button_1.Button, { color: "tertiary.main", ml: 2, plain: true, fontSize: 1, p: 1, onClick: function () { return removeSignature(index); } },
                    react_1.default.createElement(react_fontawesome_1.FontAwesomeIcon, { icon: faTimes_1.faTimes })))))); }),
        react_1.default.createElement(Button_1.Button, { mb: 2, mt: 4, primary: true, underline: true, onClick: function () { return addSignature(newSignature, signatures.length); } }, "Add alternative")));
};
exports.FilterModal = FilterModal;
var FilterInputs = function (_a) {
    var properties = _a.properties, signature = _a.signature, schema = _a.schema, onUpdate = _a.onUpdate;
    var _b = react_1.default.useState(''), searchTerm = _b[0], setSearchTerm = _b[1];
    var debouncedSetSearchTerm = (0, debounce_1.default)(setSearchTerm, 300);
    var operators = react_1.default.useMemo(function () {
        return signature.field
            ? (0, SchemaSieve_1.getOperators)(schema, signature.field, signature.refScheme)
            : [];
    }, [signature.field, signature.refScheme, schema]);
    var filteredFieldOptions = react_1.default.useMemo(function () {
        if (!searchTerm) {
            return properties;
        }
        var searchTermRegEx = new RegExp(searchTerm, 'i');
        return properties.filter(function (property) {
            return (property.title.match(searchTermRegEx) ||
                property.field.match(searchTermRegEx));
        });
    }, [searchTerm, properties]);
    react_1.default.useEffect(function () {
        if (signature.operator) {
            return;
        }
        onUpdate(__assign(__assign({}, signature), { operator: operators[0] }));
    }, [signature.field, operators]);
    return (react_1.default.createElement(Flex_1.Flex, { justifyContent: "space-between" },
        react_1.default.createElement(Select_1.Select, { mr: 1, id: "filtermodal__fieldselect", options: filteredFieldOptions, onSearch: debouncedSetSearchTerm, searchPlaceholder: "Search...", valueKey: "key", labelKey: "title", value: signature, onChange: function (_a) {
                var option = _a.option;
                if (signature.field === option.field &&
                    signature.title === option.title) {
                    return;
                }
                onUpdate(__assign(__assign(__assign({}, signature), option), { operator: undefined, value: undefined, refScheme: option.refScheme }));
            } }),
        react_1.default.createElement(Select_1.Select, { mr: 1, options: operators, valueKey: "slug", labelKey: "label", value: signature.operator, onChange: function (_a) {
                var _b;
                var option = _a.option;
                if (option.slug === ((_b = signature.operator) === null || _b === void 0 ? void 0 : _b.slug)) {
                    return;
                }
                onUpdate(__assign(__assign({}, signature), { operator: option }));
            } }),
        react_1.default.createElement(Flex_1.Flex, { maxWidth: 165 },
            react_1.default.createElement(FilterInput, { schema: schema.properties[signature.field], value: signature.value, operator: signature.operator, onUpdate: function (value) {
                    onUpdate(__assign(__assign({}, signature), { value: value }));
                }, refScheme: signature.refScheme }))));
};
var FilterInput = function (_a) {
    var _b;
    var schema = _a.schema, value = _a.value, operator = _a.operator, onUpdate = _a.onUpdate, refScheme = _a.refScheme;
    var subSchema = refScheme
        ? __assign({}, (0, SchemaSieve_2.getSubSchemaFromRefScheme)(schema, refScheme)) : __assign({}, schema);
    if (Array.isArray(subSchema.type)) {
        subSchema.type = subSchema.type.find(function (t) { return !!t; });
    }
    var model = (0, DataTypes_1.getDataModel)(subSchema);
    var uiSchema = model && 'uiSchema' in model ? ((_b = model.uiSchema) === null || _b === void 0 ? void 0 : _b.call(model, schema)) || {} : {};
    var newSchema = model && operator && 'editSchema' in model
        ? model.editSchema(subSchema, operator)
        : subSchema;
    var format = newSchema.format, type = newSchema.type;
    return (react_1.default.createElement(Form_1.Form, { schema: __assign(__assign({}, newSchema), { type: (format === null || format === void 0 ? void 0 : format.endsWith('date-time')) ||
                (0, utils_1.findInObject)(newSchema, 'maxItems') === 1
                ? 'string'
                : type }), value: value, onFormChange: function (_a) {
            var formData = _a.formData;
            return onUpdate(formData);
        }, uiSchema: __assign({ 'ui:options': { label: false, inline: true } }, uiSchema), hideSubmitButton: true }));
};
