import type { JSONSchema7 as JSONSchema, JSONSchema7Definition as JSONSchemaDefinition } from 'json-schema';
import { FilterSignature } from '.';
import { OperatorSlugs } from '../DataTypes';
export declare const FULL_TEXT_SLUG = "full_text_search";
export interface Operator<T> {
    slug: T;
    label: string;
}
interface CustomSchemaDescription {
    'x-ref-scheme'?: string[];
    'x-foreign-key-scheme'?: string[];
    'x-filter-only'?: boolean | string[];
}
export type CreateFilter = (field: string, operator: Operator<OperatorSlugs>, value: any, subSchema: JSONSchema, refScheme?: string) => JSONSchema;
export type EditSchema = (schema: JSONSchema, operator: Operator<OperatorSlugs> | undefined) => JSONSchema;
export type FilterSignatureWithKey = FilterSignature & {
    key: string;
};
export declare const getSignatures: (filter: JSONSchema) => FilterSignatureWithKey[];
export declare const createFilter: (schema: JSONSchema, signatures: FilterSignature[]) => JSONSchema;
export declare const createFullTextSearchFilter: (schema: JSONSchema, term: string) => JSONSchema;
export declare function filter<T>(filters: JSONSchema | JSONSchema[], collection: T[]): T[];
export declare function filter<T>(filters: JSONSchema | JSONSchema[], collection: Record<string, T>): Record<string, T>;
export declare const parseDescription: (schemaValue: JSONSchema | JSONSchemaDefinition) => FilterSignature | CustomSchemaDescription | null;
export declare const parseDescriptionProperty: <T extends unknown>(schemaValue: JSONSchema, property: string) => T | null;
export declare const getOperators: (schema: JSONSchema, field: string, refScheme?: string) => Array<Operator<OperatorSlugs>>;
export declare const getModelFilter: (schema: JSONSchema, field: string, operator: Operator<OperatorSlugs>, value: any) => JSONSchema;
export declare const getSchemaFormat: (schema: JSONSchema) => string | undefined;
export declare const getPropertyScheme: (schemaValue: JSONSchema | JSONSchemaDefinition) => string[] | null | undefined;
export declare const convertRefSchemeToSchemaPath: (refScheme: string | undefined) => string | undefined;
export declare const getSchemaTitle: (jsonSchema: JSONSchema, propertyKey: string, refScheme?: string | undefined) => string;
export declare const generateSchemaFromRefScheme: (schema: JSONSchema, parentProperty: string, refScheme: string | undefined) => JSONSchema;
export declare const getSubSchemaFromRefScheme: (schema: JSONSchema | JSONSchemaDefinition, refScheme?: string) => JSONSchema;
export {};
