"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSubSchemaFromRefScheme = exports.generateSchemaFromRefScheme = exports.getSchemaTitle = exports.convertRefSchemeToSchemaPath = exports.getPropertyScheme = exports.getSchemaFormat = exports.getModelFilter = exports.getOperators = exports.parseDescriptionProperty = exports.parseDescription = exports.filter = exports.createFullTextSearchFilter = exports.createFilter = exports.getSignatures = exports.FULL_TEXT_SLUG = void 0;
var ajv_1 = __importDefault(require("ajv"));
var ajv_keywords_1 = __importDefault(require("ajv-keywords"));
var DataTypes_1 = require("../DataTypes");
var utils_1 = require("../../utils");
var pickBy_1 = __importDefault(require("lodash/pickBy"));
var utils_2 = require("../DataTypes/utils");
var pick_1 = __importDefault(require("lodash/pick"));
var get_1 = __importDefault(require("lodash/get"));
var ajv = new ajv_1.default();
(0, ajv_keywords_1.default)(ajv, ['regexp', 'formatMaximum', 'formatMinimum']);
exports.FULL_TEXT_SLUG = 'full_text_search';
var getSignatures = function (filter) {
    var _a;
    var signatures = filter.anyOf.map(function (f) {
        return (0, exports.parseDescription)(f);
    });
    return ((_a = signatures.filter(function (s) { return s !== null; })) !== null && _a !== void 0 ? _a : []).map(function (s) { return (__assign(__assign({}, s), { key: !!s.refScheme ? "".concat(s.field, "__").concat(s.refScheme) : s.field })); });
};
exports.getSignatures = getSignatures;
var getSignatureLabel = function (schema, value) {
    if (Array.isArray(schema.oneOf)) {
        var oneOf = schema.oneOf.find(function (oneOf) { return oneOf && typeof oneOf === 'object' && oneOf.const === value; });
        return typeof oneOf === 'object' ? oneOf.title : undefined;
    }
    return undefined;
};
var createFilter = function (schema, signatures) {
    var anyOf = signatures.map(function (_a) {
        var field = _a.field, operator = _a.operator, value = _a.value, refScheme = _a.refScheme;
        var subSchema = !!refScheme
            ? (0, exports.generateSchemaFromRefScheme)(schema, field, refScheme)
            : __assign({}, schema.properties[field]);
        var label = getSignatureLabel(subSchema, value);
        var model = (0, DataTypes_1.getDataModel)(subSchema);
        if (!model) {
            return {};
        }
        return __assign({ $id: (0, utils_1.randomString)(), title: operator.slug, description: (0, utils_2.getJsonDescription)(subSchema.title, field, operator, value, label, refScheme), type: 'object' }, model.createFilter(field, operator, value, subSchema, refScheme));
    });
    return {
        $id: (0, utils_1.randomString)(),
        anyOf: anyOf,
    };
};
exports.createFilter = createFilter;
var createFullTextSearchFilter = function (schema, term) {
    var items = !!schema.properties
        ? Object.entries(schema.properties).reduce(function (itemsAccumulator, entry) {
            var _a;
            var key = entry[0], item = entry[1];
            var model = (0, DataTypes_1.getDataModel)(item);
            if (((_a = item.type) === null || _a === void 0 ? void 0 : _a.includes('boolean')) ||
                (0, DataTypes_1.isDateTimeFormat)(item.format) ||
                !model) {
                return itemsAccumulator;
            }
            itemsAccumulator.push({
                key: key,
                schema: item,
                model: model,
            });
            return itemsAccumulator;
        }, [])
        : [];
    var filter = generateFullTextSearchAjvFilter(term, items);
    return filter;
};
exports.createFullTextSearchFilter = createFullTextSearchFilter;
var generateFullTextSearchAjvFilter = function (term, items) {
    var operator = {
        label: 'full text search',
        slug: exports.FULL_TEXT_SLUG,
    };
    return {
        $id: (0, utils_1.randomString)(),
        title: exports.FULL_TEXT_SLUG,
        anyOf: [
            {
                title: exports.FULL_TEXT_SLUG,
                description: (0, utils_2.getJsonDescription)('Any field', 'any', operator, term, undefined, undefined),
                anyOf: items
                    .map(function (_a) {
                    var key = _a.key, schema = _a.schema, model = _a.model;
                    if (!model) {
                        return {};
                    }
                    return model.createFilter(key, operator, term, schema);
                })
                    .filter(function (item) { return Object.keys(item).length > 0; }),
            },
        ],
    };
};
function filter(filters, collection) {
    ajv.removeSchema(/^.*$/);
    var validators = Array.isArray(filters)
        ? filters.map(function (s) { return ajv.compile(s); })
        : [ajv.compile(filters)];
    if (Array.isArray(collection)) {
        return collection.filter(function (m) { return validators.every(function (v) { return v(m); }); });
    }
    return (0, pickBy_1.default)(collection, function (m) { return validators.every(function (v) { return v(m); }); });
}
exports.filter = filter;
var parseDescription = function (schemaValue) {
    return schemaValue &&
        typeof schemaValue !== 'boolean' &&
        schemaValue.description &&
        (0, utils_1.isJson)(schemaValue.description)
        ? JSON.parse(schemaValue.description)
        : null;
};
exports.parseDescription = parseDescription;
var parseDescriptionProperty = function (schemaValue, property) {
    var description = (0, exports.parseDescription)(schemaValue);
    return description && property in description
        ? description[property]
        : null;
};
exports.parseDescriptionProperty = parseDescriptionProperty;
var getOperators = function (schema, field, refScheme) {
    var subSchema = (refScheme
        ? (0, exports.getSubSchemaFromRefScheme)(schema.properties[field], refScheme)
        : schema.properties[field]);
    var model = (0, DataTypes_1.getDataModel)(subSchema);
    if (!model) {
        return [];
    }
    return Object.entries(model.operators(subSchema)).map(function (_a) {
        var key = _a[0], value = _a[1];
        return ({
            slug: key,
            label: value,
        });
    });
};
exports.getOperators = getOperators;
var getModelFilter = function (schema, field, operator, value) {
    var model = (0, DataTypes_1.getDataModel)(schema);
    if (!model) {
        throw new Error("getModelFilter: model not defied, something is probably wrong with the type declaration in the schema! field: ".concat(field, ", type: ").concat(schema.type));
    }
    var filter = model.createFilter(field, operator, value, schema);
    return filter;
};
exports.getModelFilter = getModelFilter;
var getSchemaFormat = function (schema) {
    var _a;
    var property = (0, exports.getSubSchemaFromRefScheme)(schema);
    var format = (_a = property.format) !== null && _a !== void 0 ? _a : schema.format;
    return format;
};
exports.getSchemaFormat = getSchemaFormat;
var getPropertyScheme = function (schemaValue) {
    var _a;
    var json = (0, exports.parseDescription)(schemaValue);
    return json && ('x-foreign-key-scheme' in json || 'x-ref-scheme' in json)
        ? (_a = json['x-foreign-key-scheme']) !== null && _a !== void 0 ? _a : json['x-ref-scheme']
        : null;
};
exports.getPropertyScheme = getPropertyScheme;
var convertRefSchemeToSchemaPath = function (refScheme) {
    return !!refScheme
        ? refScheme
            .split('.')
            .join('.properties.')
            .replace(/\[\d+\]/g, '.items')
        :
            refScheme;
};
exports.convertRefSchemeToSchemaPath = convertRefSchemeToSchemaPath;
var getSchemaTitle = function (jsonSchema, propertyKey, refScheme) {
    var _a, _b, _c;
    if (!refScheme) {
        return (jsonSchema === null || jsonSchema === void 0 ? void 0 : jsonSchema.title) || propertyKey;
    }
    return ((_c = (_b = (_a = (0, exports.getSubSchemaFromRefScheme)(jsonSchema, refScheme)) === null || _a === void 0 ? void 0 : _a.title) !== null && _b !== void 0 ? _b : jsonSchema.title) !== null && _c !== void 0 ? _c : propertyKey);
};
exports.getSchemaTitle = getSchemaTitle;
var generateSchemaFromRefScheme = function (schema, parentProperty, refScheme) {
    var _a, _b, _c, _d;
    var propertySchema = (_b = (_a = schema.properties) === null || _a === void 0 ? void 0 : _a[parentProperty]) !== null && _b !== void 0 ? _b : schema;
    if (!refScheme) {
        return propertySchema;
    }
    var convertedRefScheme = propertySchema.items
        ? "items.properties.".concat((0, exports.convertRefSchemeToSchemaPath)(refScheme))
        : "properties.".concat((0, exports.convertRefSchemeToSchemaPath)(refScheme));
    var typePaths = [];
    var ongoingIncrementalPath = [];
    convertedRefScheme.split('.').forEach(function (key) {
        if (['properties', 'items'].includes(key)) {
            typePaths.push(__spreadArray(__spreadArray([], ongoingIncrementalPath, true), ['type'], false));
        }
        ongoingIncrementalPath.push(key);
    });
    if (ongoingIncrementalPath.length) {
        typePaths.push(ongoingIncrementalPath);
    }
    var referenceSchema = (0, get_1.default)(propertySchema, convertedRefScheme);
    var referenceSchemaDescription = (_c = (0, exports.parseDescription)(referenceSchema)) !== null && _c !== void 0 ? _c : {};
    return __assign(__assign(__assign({}, propertySchema), { description: "".concat(JSON.stringify(Object.assign(referenceSchemaDescription, {
            'x-ref-scheme': [refScheme],
        }))), title: (_d = referenceSchema === null || referenceSchema === void 0 ? void 0 : referenceSchema.title) !== null && _d !== void 0 ? _d : propertySchema.title }), (0, pick_1.default)(propertySchema, typePaths));
};
exports.generateSchemaFromRefScheme = generateSchemaFromRefScheme;
var getSubSchemaFromRefScheme = function (schema, refScheme) {
    var _a;
    var referenceScheme = refScheme || ((_a = (0, exports.getPropertyScheme)(schema)) === null || _a === void 0 ? void 0 : _a[0]);
    var convertedRefScheme = (0, exports.convertRefSchemeToSchemaPath)(referenceScheme);
    if (!convertedRefScheme) {
        return schema;
    }
    var properties = (0, utils_1.findInObject)(schema, 'properties');
    return (0, get_1.default)(properties, convertedRefScheme);
};
exports.getSubSchemaFromRefScheme = getSubSchemaFromRefScheme;
