"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var enzyme_1 = require("enzyme");
var react_1 = __importDefault(require("react"));
var sinon_1 = __importDefault(require("sinon"));
var __1 = require("../../");
var NotificationsComponent = function (_a) {
    var content = _a.content, idToRemove = _a.idToRemove;
    return (react_1.default.createElement(__1.Provider, null,
        react_1.default.createElement(__1.NotificationsContainer, null),
        react_1.default.createElement(__1.Button, { onClick: function () { return __1.notifications.addNotification(content); } }, "Add text notification"),
        react_1.default.createElement(__1.Button, { onClick: function () { return __1.notifications.removeNotification(idToRemove); } }, "Remove text notification")));
};
describe('Notifications component', function () {
    it('can add a notification', function () {
        var component = (0, enzyme_1.mount)(react_1.default.createElement(NotificationsComponent, { content: 'A notification' }));
        component.find('button').first().simulate('click');
        expect(component.find('.rnc__notification-item').text()).toBe('A notification');
    });
    it('can remove a notification using the API', function () {
        var id = 'notification-id';
        var component = (0, enzyme_1.mount)(react_1.default.createElement(NotificationsComponent, { content: { content: 'A notification', id: id }, idToRemove: id }));
        component.find('button').first().simulate('click');
        component.find('button').at(2).simulate('click');
        component.find('.rnc__notification-item').first().simulate('transitionend');
        expect(component.find('.rnc__notification-item')).toHaveLength(0);
    });
    it('can remove a notification by clicking on the dismiss button', function () {
        var component = (0, enzyme_1.mount)(react_1.default.createElement(NotificationsComponent, { content: 'A notification' }));
        component.find('button').first().simulate('click');
        component
            .find('.rnc__notification-item')
            .find('button')
            .first()
            .simulate('click');
        component.find('.rnc__notification-item').first().simulate('transitionend');
        expect(component.find('.rnc__notification-item')).toHaveLength(0);
    });
    it('calls the onDismiss callback when the dismiss button is clicked', function () {
        var callback = sinon_1.default.spy();
        var component = (0, enzyme_1.mount)(react_1.default.createElement(NotificationsComponent, { content: { content: 'A notification', onDismiss: callback } }));
        component.find('button').first().simulate('click');
        component
            .find('.rnc__notification-item')
            .find('button')
            .first()
            .simulate('click');
        expect(callback.callCount).toEqual(1);
    });
    it('disappears after the duration passes', function () { return __awaiter(void 0, void 0, void 0, function () {
        var component;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    component = (0, enzyme_1.mount)(react_1.default.createElement(NotificationsComponent, { content: { content: 'A notification', duration: 20 } }));
                    component.find('button').first().simulate('click');
                    component.find('.rnc__notification-item').first().simulate('transitionend');
                    return [4, new Promise(function (r) { return setTimeout(r, 200); })];
                case 1:
                    _a.sent();
                    component.find('.rnc__notification-item').first().simulate('transitionend');
                    expect(component.find('.rnc__notification-item')).toHaveLength(0);
                    return [2];
            }
        });
    }); });
    it('displays notifications in the expected position', function () {
        var container = 'bottom-right';
        var component = (0, enzyme_1.mount)(react_1.default.createElement(NotificationsComponent, { content: {
                container: container,
                content: 'A notification',
            } }));
        component.find('button').first().simulate('click');
        expect(component.find(".rnc__notification-container--".concat(container)).text()).toBe('A notification');
    });
});
