"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateUiSchemaMetaSchema = void 0;
var first_1 = __importDefault(require("lodash/first"));
var forEach_1 = __importDefault(require("lodash/forEach"));
var get_1 = __importDefault(require("lodash/get"));
var without_1 = __importDefault(require("lodash/without"));
var uniq_1 = __importDefault(require("lodash/uniq"));
var keys_1 = __importDefault(require("lodash/keys"));
var widgets_1 = require("../widgets");
var index_1 = require("../index");
var widgets_2 = require("../widgets");
var widget_util_1 = require("../widgets/widget-util");
var getBaseMetaSchema = function () { return ({
    title: 'Renderer UI Schema',
    type: ['object', 'null'],
    properties: {
        'ui:title': {
            type: ['string', 'null'],
        },
        'ui:description': {
            type: ['string', 'null'],
        },
        'ui:value': {
            type: ['string', 'object', 'null'],
        },
        'ui:options': {
            type: 'object',
        },
        'ui:explicit': {
            type: 'boolean',
        },
    },
}); };
var generateArrayMetaSchema = function (metaSchema, _a) {
    var value = _a.value, schema = _a.schema, uiSchema = _a.uiSchema, extraContext = _a.extraContext, extraFormats = _a.extraFormats;
    var arrayValue = value;
    var itemsUiSchema = (0, get_1.default)(uiSchema, 'items', {});
    var itemsSchema = (0, get_1.default)(schema, 'items', {});
    metaSchema.properties.items = (0, exports.generateUiSchemaMetaSchema)({
        value: (0, first_1.default)(arrayValue),
        schema: typeof itemsSchema === 'boolean' ? {} : itemsSchema,
        uiSchema: itemsUiSchema,
        extraContext: extraContext,
        extraFormats: extraFormats,
    });
};
var generateObjectMetaSchema = function (metaSchema, _a) {
    var value = _a.value, schema = _a.schema, uiSchema = _a.uiSchema, extraContext = _a.extraContext, extraFormats = _a.extraFormats;
    metaSchema.properties['ui:order'] = {
        type: ['array'],
        items: {
            type: 'string',
            enum: (0, keys_1.default)(schema === null || schema === void 0 ? void 0 : schema.properties).concat(['*']),
        },
    };
    var propertyNames = (0, widgets_2.getObjectPropertyNames)({
        value: value || '',
        schema: schema,
        uiSchema: uiSchema || {},
    });
    (0, forEach_1.default)(propertyNames, function (propertyName) {
        var subSchema = (0, get_1.default)(schema, ['properties', propertyName], {});
        var subUiSchema = (0, get_1.default)(uiSchema, propertyName, {});
        metaSchema.properties[propertyName] = (0, exports.generateUiSchemaMetaSchema)({
            value: (0, get_1.default)(value, propertyName),
            schema: typeof subSchema === 'boolean' ? {} : subSchema,
            uiSchema: subUiSchema,
            extraContext: extraContext,
            extraFormats: extraFormats,
        });
    });
};
var setWidgetOptions = function (metaSchema, type) {
    var widgetKeys = __spreadArray([
        type
    ], widgets_1.defaultFormats
        .filter(function (x) { var _a, _b; return (_b = (_a = x.widget) === null || _a === void 0 ? void 0 : _a.supportedTypes) === null || _b === void 0 ? void 0 : _b.includes(type); })
        .map(function (x) { return x.name; }), true);
    metaSchema.properties['ui:widget'] = {
        oneof: [
            {
                type: 'string',
                enum: (0, without_1.default)((0, uniq_1.default)(widgetKeys), 'default'),
            },
            {
                type: 'object',
            },
        ],
    };
};
var setUiOptions = function (_a) {
    var metaSchema = _a.metaSchema, format = _a.format, _b = _a.input, value = _b.value, uiSchema = _b.uiSchema;
    var widget = (0, index_1.getWidget)(value, format, (0, get_1.default)(uiSchema, 'ui:widget'));
    metaSchema.properties['ui:options'] = {
        type: 'object',
        properties: __assign(__assign({}, widgets_2.WidgetWrapperUiOptions), widget.uiOptions),
    };
};
var generateUiSchemaMetaSchema = function (_a) {
    var unprocessedValue = _a.value, uiSchema = _a.uiSchema, schema = _a.schema, extraContext = _a.extraContext, extraFormats = _a.extraFormats;
    var metaSchema = getBaseMetaSchema();
    var processedUiSchema = (0, widget_util_1.transformUiSchema)({
        value: unprocessedValue,
        uiSchema: uiSchema,
        extraContext: extraContext,
    });
    var input = {
        value: (0, get_1.default)(processedUiSchema, 'ui:value', unprocessedValue),
        schema: schema,
        uiSchema: processedUiSchema,
        extraContext: extraContext,
        extraFormats: extraFormats,
    };
    var type = (0, index_1.getType)(input.value);
    if (type === 'object') {
        generateObjectMetaSchema(metaSchema, input);
    }
    else if (type === 'array') {
        generateArrayMetaSchema(metaSchema, input);
    }
    if (type) {
        setWidgetOptions(metaSchema, type);
    }
    setUiOptions({ metaSchema: metaSchema, format: schema === null || schema === void 0 ? void 0 : schema.format, input: input });
    return metaSchema;
};
exports.generateUiSchemaMetaSchema = generateUiSchemaMetaSchema;
