"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.truncateHash = exports.getObjectPropertyNames = exports.getArrayItems = exports.getBestSchemaMatch = exports.transformUiSchema = exports.withOptionProps = exports.timeSince = exports.formatTimestamp = exports.widgetFactory = void 0;
var React = __importStar(require("react"));
var date_fns_1 = require("date-fns");
var skhema_1 = __importDefault(require("skhema"));
var json_e_1 = __importDefault(require("json-e"));
var merge_1 = __importDefault(require("lodash/merge"));
var pickBy_1 = __importDefault(require("lodash/pickBy"));
var difference_1 = __importDefault(require("lodash/difference"));
var isArray_1 = __importDefault(require("lodash/isArray"));
var keys_1 = __importDefault(require("lodash/keys"));
var has_1 = __importDefault(require("lodash/has"));
var get_1 = __importDefault(require("lodash/get"));
var pick_1 = __importDefault(require("lodash/pick"));
function widgetFactory(displayName, uiOptions, supportedTypes) {
    return function (widgetFn) {
        var widget = widgetFn;
        Object.assign(widget, {
            displayName: displayName,
            uiOptions: uiOptions,
            supportedTypes: supportedTypes,
        });
        return widget;
    };
}
exports.widgetFactory = widgetFactory;
var DATE_FORMAT = 'MMM do yyyy';
var TIME_FORMAT = 'h:mm a';
function formatTimestamp(timestamp, uiSchema) {
    if (uiSchema === void 0) { uiSchema = {}; }
    if (!timestamp) {
        return '';
    }
    var uiFormat = (0, get_1.default)(uiSchema, ['ui:options', 'dtFormat']) ||
        "".concat(DATE_FORMAT, ", ").concat(TIME_FORMAT);
    return (0, date_fns_1.format)(new Date(timestamp), uiFormat);
}
exports.formatTimestamp = formatTimestamp;
var timeSince = function (timestamp, suffix) {
    if (suffix === void 0) { suffix = true; }
    return (0, date_fns_1.formatDistance)(new Date(timestamp), new Date(), { addSuffix: suffix });
};
exports.timeSince = timeSince;
function withOptionProps(uiOptions) {
    return function (Component) {
        var wrapped = function (props) {
            var extraProps = pick_1.default.apply(void 0, __spreadArray([(0, get_1.default)(props.uiSchema, 'ui:options', {})], (0, keys_1.default)(uiOptions), false));
            return React.createElement(Component, __assign({}, props, extraProps));
        };
        wrapped.displayName = Component.displayName;
        wrapped.uiOptions = Component.uiOptions;
        wrapped.supportedTypes = Component.supportedTypes;
        return wrapped;
    };
}
exports.withOptionProps = withOptionProps;
var transformUiSchema = function (_a) {
    var value = _a.value, uiSchema = _a.uiSchema, extraContext = _a.extraContext;
    if (uiSchema == null) {
        return {};
    }
    var context = __assign({ source: value !== null && value !== void 0 ? value : '' }, extraContext);
    if (typeof value === 'object') {
        var trimmedUiSchema = (0, pickBy_1.default)(uiSchema, function (_, k) { return k.startsWith('ui:'); });
        var processedUiSchema = (0, json_e_1.default)(trimmedUiSchema, context);
        return (0, merge_1.default)({}, uiSchema, processedUiSchema);
    }
    return (0, json_e_1.default)(uiSchema, context);
};
exports.transformUiSchema = transformUiSchema;
var getBestSchemaMatch = function (schema, value) {
    if (!(schema === null || schema === void 0 ? void 0 : schema.anyOf)) {
        return schema;
    }
    var mostRelevantSchema = schema.anyOf.reduce(function (mostRelevantSchema, anyOfItem) {
        var match = skhema_1.default.match(anyOfItem, value);
        if (match.valid && match.score > mostRelevantSchema.score) {
            return {
                schema: anyOfItem,
                score: match.score,
            };
        }
        return mostRelevantSchema;
    }, {
        schema: schema,
        score: 0,
    });
    return mostRelevantSchema.schema;
};
exports.getBestSchemaMatch = getBestSchemaMatch;
var getArrayItems = function (_a) {
    var value = _a.value, schema = _a.schema, uiSchema = _a.uiSchema, extraContext = _a.extraContext, extraFormats = _a.extraFormats;
    if (!(0, isArray_1.default)(value)) {
        throw new Error("Value must be an array (not '".concat(typeof value, "')"));
    }
    var maxItems = (0, get_1.default)(uiSchema, ['ui:options', 'truncate'], value.length);
    var items = value.slice(0, maxItems).map(function (item) {
        var itemSchema = (0, get_1.default)(schema, 'items', {});
        var itemUiSchema = (0, get_1.default)(uiSchema, 'items', {});
        var processedUiSchema = (0, exports.transformUiSchema)({
            value: item,
            uiSchema: itemUiSchema,
            extraContext: extraContext,
        });
        return {
            value: item,
            schema: itemSchema,
            uiSchema: processedUiSchema,
            extraContext: extraContext,
            extraFormats: extraFormats,
        };
    });
    if (maxItems < value.length) {
        items.push({
            value: "+ ".concat(value.length - maxItems, " more"),
            schema: {
                type: 'string',
            },
            uiSchema: {},
            extraContext: extraContext,
            extraFormats: extraFormats,
        });
    }
    return items;
};
exports.getArrayItems = getArrayItems;
var getMaterializedPropertyNames = function (uiSchema) {
    return (0, keys_1.default)(uiSchema).filter(function (uiSchemaKey) {
        return uiSchemaKey.startsWith('ui:field:');
    });
};
function getObjectPropertyNames(_a) {
    var value = _a.value, schema = _a.schema, uiSchema = _a.uiSchema;
    if (typeof value !== 'object') {
        throw new Error("Cannot get object property names from a value of type '".concat(typeof value, "'"));
    }
    var uiSchemaPropertyNames = getMaterializedPropertyNames(uiSchema);
    var schemaPropertyNames = (0, get_1.default)(uiSchema, ['ui:order'], (0, keys_1.default)((0, get_1.default)(schema, 'properties'))) || [];
    var nonSchemaPropertyNames = (0, difference_1.default)((0, keys_1.default)(value) || [], schemaPropertyNames);
    var allObjectPropertyNames = __spreadArray(__spreadArray(__spreadArray([], uiSchemaPropertyNames, true), schemaPropertyNames, true), nonSchemaPropertyNames, true);
    return (0, get_1.default)(uiSchema, 'ui:explicit', false)
        ? allObjectPropertyNames.filter(function (propName) { return (0, has_1.default)(uiSchema, propName); })
        : allObjectPropertyNames;
}
exports.getObjectPropertyNames = getObjectPropertyNames;
var truncateHash = function (str, maxLength) {
    if (maxLength === void 0) { maxLength = 7; }
    if (!str || str.length < maxLength) {
        return str;
    }
    return str.substring(0, maxLength);
};
exports.truncateHash = truncateHash;
