"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.withCustomColumns = exports.WithConditionalRowClasses = exports.WithHighlightedRows = exports.WithAnchorRows = exports.WithPrefix = exports.WithRowClick = exports.WithCheckboxes = exports.Sorted = exports.WithFuzzyPager = exports.WithPager = exports.Default = void 0;
var react_1 = __importDefault(require("react"));
var utils_1 = require("../../stories/utils");
var pokedex_1 = __importDefault(require("../../stories/assets/pokedex"));
var _1 = require("./");
var prefixNum = function (num) {
    return num.toString().length === 1 ? "0".concat(num) : num;
};
var columns = [
    {
        title: 'Name',
        field: 'Name',
        sortable: true,
        selected: true,
    },
    {
        title: 'National Pokedex Number',
        field: 'pokedex_number',
        sortable: true,
        selected: true,
        render: function (value) { return react_1.default.createElement("code", null, value); },
    },
    {
        title: 'Category',
        field: 'Category',
        sortable: true,
        selected: true,
    },
    {
        title: 'First Seen',
        field: 'first_seen',
        sortable: true,
        selected: false,
        render: function (value) {
            if (value == null) {
                return null;
            }
            var d = new Date(value);
            return (react_1.default.createElement("span", null,
                d.getFullYear(),
                "-",
                prefixNum(d.getMonth() + 1),
                "-",
                prefixNum(d.getDay() + 1)));
        },
    },
];
exports.default = {
    title: 'Core/Table',
    component: _1.Table,
    args: {
        columns: columns,
        data: pokedex_1.default,
        rowKey: 'pokedex_number',
        onCheck: null,
    },
};
var TableWithCheckboxesTemplate = (0, utils_1.createTemplate)(function (props) {
    var _a;
    var _b = react_1.default.useState((_a = props.checkedItems) !== null && _a !== void 0 ? _a : []), selected = _b[0], setSelected = _b[1];
    return (react_1.default.createElement(_1.Table, __assign({}, props, { checkedItems: selected, onCheck: function (items) { return setSelected(items !== null && items !== void 0 ? items : []); } })));
});
var Template = (0, utils_1.createTemplate)(_1.Table);
exports.Default = (0, utils_1.createStory)(Template, {});
exports.WithPager = (0, utils_1.createStory)(Template, {
    usePager: true,
    itemsPerPage: 3,
    pagerPosition: 'both',
});
exports.WithFuzzyPager = (0, utils_1.createStory)(Template, {
    usePager: true,
    itemsPerPage: 3,
    pagerPosition: 'both',
    fuzzyPager: true,
    data: pokedex_1.default.slice(0, 5),
});
exports.Sorted = (0, utils_1.createStory)(Template, {
    sort: { field: 'Name', reverse: true },
});
exports.WithCheckboxes = (0, utils_1.createStory)(TableWithCheckboxesTemplate, {
    checkedItems: pokedex_1.default.slice(0, 3),
});
exports.WithRowClick = (0, utils_1.createStory)(Template, {
    onRowClick: function () { return null; },
});
exports.WithPrefix = (0, utils_1.createStory)(Template, {
    tbodyPrefix: [
        react_1.default.createElement("tr", { key: 1 },
            react_1.default.createElement("td", { colSpan: columns.length },
                react_1.default.createElement("p", { style: { textAlign: 'center' } }, "Row 1"))),
        react_1.default.createElement("tr", { key: 2 },
            react_1.default.createElement("td", { colSpan: columns.length },
                react_1.default.createElement("p", { style: { textAlign: 'center' } }, "Row 2"))),
    ],
});
exports.WithAnchorRows = (0, utils_1.createStory)(Template, {
    getRowHref: function (row) { return "https://www.pokemon.com/uk/pokedex/".concat(row.Name); },
    rowAnchorAttributes: { target: '_blank' },
});
exports.WithHighlightedRows = (0, utils_1.createStory)(Template, {
    highlightedRows: [2, 5],
});
exports.WithConditionalRowClasses = (0, utils_1.createStory)(Template, {
    getRowClass: function (pokemon) {
        var classNames = ['pokemon'];
        if (pokemon.caught) {
            classNames.push('pokemon--caught');
        }
        if (pokemon.Abilities.length === 1) {
            classNames.push('pokemon--one-dimensional');
        }
        return classNames;
    },
});
exports.withCustomColumns = (0, utils_1.createStory)(Template, {
    enableCustomColumns: true,
});
