"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getResourceTagSubmitInfo = exports.groupResourcesByTags = exports.getResourceTags = exports.getTagKeyValueComposite = exports.TAGS_COLUMN_KEY = void 0;
var keys_1 = __importDefault(require("lodash/keys"));
var flatMap_1 = __importDefault(require("lodash/flatMap"));
var map_1 = __importDefault(require("lodash/map"));
var groupBy_1 = __importDefault(require("lodash/groupBy"));
exports.TAGS_COLUMN_KEY = 'Tags';
var getTagKeyValueComposite = function (tagKey, value) {
    return "".concat(tagKey, ": ").concat(value);
};
exports.getTagKeyValueComposite = getTagKeyValueComposite;
var getResourceTags = function (item, tagField) { var _a; return ((_a = (tagField in item ? item[tagField] : null)) !== null && _a !== void 0 ? _a : []); };
exports.getResourceTags = getResourceTags;
var groupResourcesByTags = function (items, tagField) {
    var resourceTagInfos = (0, flatMap_1.default)(items, function (item) {
        var tags = (0, exports.getResourceTags)(item, tagField);
        return tags.map(function (tag) { return ({
            tag_key_value: (0, exports.getTagKeyValueComposite)(tag.tag_key, tag.value),
            tag_key: tag.tag_key,
            value: tag.value,
            item: item,
        }); });
    });
    var tagsByTagKeyValue = (0, groupBy_1.default)(resourceTagInfos, 'tag_key_value');
    var tagsWithItems = (0, map_1.default)((0, keys_1.default)(tagsByTagKeyValue).sort(), function (tagKeyValue) {
        var tags = tagsByTagKeyValue[tagKeyValue];
        var firstTag = tags[0];
        return {
            tag_key: firstTag.tag_key,
            value: firstTag.value,
            items: (0, map_1.default)(tags, 'item'),
        };
    });
    return tagsWithItems;
};
exports.groupResourcesByTags = groupResourcesByTags;
var getResourceTagSubmitInfo = function (tags) {
    var submitInfo = {
        added: [],
        updated: [],
        deleted: [],
    };
    tags.forEach(function (tag) {
        if (tag.state && tag.state in submitInfo) {
            Array.prototype.push.apply(submitInfo[tag.state], tag.items.map(function (item) { return ({
                resourceId: item.id,
                tag_key: tag.tag_key,
                value: tag.value,
            }); }));
        }
    });
    return submitInfo;
};
exports.getResourceTagSubmitInfo = getResourceTagSubmitInfo;
