"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.sanitizeBlocks = exports.htmlBlocks = exports.codeBlocks = void 0;
var react_1 = __importDefault(require("react"));
var react_2 = require("@testing-library/react");
var __1 = require("../../");
var _1 = require(".");
var specsuite_1 = __importDefault(require("./specsuite"));
exports.codeBlocks = "\n## Code blocks\n\n```\n// This is plaintext\nconst foo = () => {\nreturn 'bar'\n}\n```\n\n```javascript\n// This is javascript\nconst foo = () => {\n  return 'bar'\n}\n```\n";
exports.htmlBlocks = "\n\n## Inline HTML\n\n<strong>An image:</strong>\n<br>\n<img src=\"https://balena.io\" />\n<br>\n<em>A link:</em>\n<a target=\"_blank\" href=\"http://github.com/\">http://github.com/</a>\n\n## Keyboard keys\n\n<kbd>cmd</kbd> + <kbd>alt</kbd> + <kbd>shift</kbd> + <kbd>a</kbd>\n";
exports.sanitizeBlocks = "\n<img src=x onerror=alert(123) />\n";
describe('Markdown component', function () {
    it('should not highlight code when disabled', function () {
        var container = (0, react_2.render)(react_1.default.createElement(__1.Provider, null,
            react_1.default.createElement(_1.Markdown, { disableCodeHighlight: true }, exports.codeBlocks))).container;
        expect(container).toMatchSnapshot();
    });
    it('should not sanitize html when disabled', function () {
        var container = (0, react_2.render)(react_1.default.createElement(__1.Provider, null,
            react_1.default.createElement(_1.Markdown, { sanitizerOptions: null }, exports.sanitizeBlocks))).container;
        expect(container).toMatchSnapshot();
    });
    it('should not render raw html when disabled', function () {
        var container = (0, react_2.render)(react_1.default.createElement(__1.Provider, null,
            react_1.default.createElement(_1.Markdown, { disableRawHtml: true }, exports.htmlBlocks))).container;
        expect(container).toMatchSnapshot();
    });
    it('should decorate the text matching the condition', function () {
        var decorators = [
            {
                match: new RegExp('(\\s|^)((@{1,2}|#|!{1,2})[a-z\\d-_\\/]+(\\.[a-z\\d-_\\/]+)*)(\\s|$)', 'gmi'),
                captureGroupIndex: 2,
                component: 'span',
                properties: {
                    style: {
                        color: 'green',
                    },
                },
            },
        ];
        var container = (0, react_2.render)(react_1.default.createElement(__1.Provider, null,
            react_1.default.createElement(_1.Markdown, { decorators: decorators }, "@good foo @bad@bad [@good](https://github.com) bar@bad baz qux. `Is @bad inside code` @good @good"))).container;
        expect(container).toMatchSnapshot();
    });
    specsuite_1.default.forEach(function (testCase) {
        it(testCase.name, function () {
            var container = (0, react_2.render)(react_1.default.createElement(__1.Provider, null,
                react_1.default.createElement(_1.Markdown, { sanitizerOptions: testCase.sanitizerOptions }, testCase.source))).container;
            expect(container).toMatchSnapshot();
        });
    });
});
