"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var enzyme_1 = require("enzyme");
var react_1 = __importDefault(require("react"));
var test_utils_1 = require("react-dom/test-utils");
var __1 = require("../");
var useBreakpoint_1 = require("./useBreakpoint");
var theme_1 = require("../theme");
var Sample = function () {
    var theme = (0, __1.useTheme)();
    return react_1.default.createElement("span", null, theme.font);
};
test('useTheme should return correct theme object', function () {
    var theme = {
        font: 'Arial',
    };
    var component = (0, enzyme_1.mount)(react_1.default.createElement(__1.Provider, { theme: theme },
        react_1.default.createElement(Sample, null)));
    var text = component.find(Sample).text();
    expect(text).toEqual('Arial');
});
var resizeWindow = function (width) {
    if (width === void 0) { width = 600; }
    global.window.innerWidth = width;
    global.window.dispatchEvent(new Event('resize'));
};
var HookContainer = function (_a) {
    var children = _a.children, values = _a.values;
    return children((0, useBreakpoint_1.useBreakpoint)(values));
};
var testHook = function (values) {
    var retrunValues;
    (0, enzyme_1.mount)(react_1.default.createElement(__1.Provider, null,
        react_1.default.createElement(HookContainer, { values: values }, function (hookVal) {
            retrunValues = hookVal;
            return null;
        })));
    return retrunValues;
};
describe('should test useBreakpoint hook in multiple resolutions', function () {
    var values = theme_1.breakpoints.map(function (b) { return "less than ".concat(b); });
    var table = theme_1.breakpoints.map(function (b, index) { return ["name: ".concat(b), b, values[index]]; });
    test.each(table)('useBreakpoint should return %s value with %d resolution', function (_name, resolution, expectedResult) {
        (0, test_utils_1.act)(function () {
            resizeWindow(resolution - 1);
        });
        var hookValue = testHook(values);
        expect(hookValue).toEqual(expectedResult);
    });
});
