"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPreferredVersionOpts = exports.transformVersions = void 0;
var uniq_1 = __importDefault(require("lodash/uniq"));
var partition_1 = __importDefault(require("lodash/partition"));
var transformVersions = function (versions) {
    var optsByVersion = {};
    versions.forEach(function (version) {
        var _a;
        var _b;
        var existingSelectionOpt = optsByVersion[version.strippedVersion];
        var title = (_b = (version.variant === 'dev' ? existingSelectionOpt === null || existingSelectionOpt === void 0 ? void 0 : existingSelectionOpt.title : null)) !== null && _b !== void 0 ? _b : version.strippedVersion;
        optsByVersion[version.strippedVersion] = __assign({ title: title, value: version.strippedVersion, osType: version.osType, line: version.line, isRecommended: version.isRecommended, knownIssueList: version.known_issue_list }, (!version.variant
            ? {
                hasPrebuiltVariants: false,
                rawVersion: version.raw_version,
            }
            : {
                hasPrebuiltVariants: true,
                rawVersions: __assign(__assign({}, (existingSelectionOpt != null &&
                    'rawVersions' in existingSelectionOpt &&
                    existingSelectionOpt.rawVersions)), (_a = {}, _a[version.variant] = version.raw_version, _a)),
            }));
    });
    return Object.values(optsByVersion);
};
exports.transformVersions = transformVersions;
var LEGACY_OS_VERSION_MAJOR = 1;
var getPreferredVersionOpts = function (versionOpts) {
    var _a = (0, partition_1.default)(versionOpts, function (v) {
        var _a;
        var major = (_a = v.value.match(/\d+/)) === null || _a === void 0 ? void 0 : _a.join();
        return major && parseInt(major, 10) > LEGACY_OS_VERSION_MAJOR;
    }), supportedVersions = _a[0], legacyVersions = _a[1];
    var opts = supportedVersions.length ? supportedVersions : legacyVersions;
    var lines = (0, uniq_1.default)(opts.map(function (option) { return option.line; }));
    var hasMultipleLines = lines.length > 1;
    if (hasMultipleLines) {
        var preferredMultilineOpts_1 = {};
        opts.forEach(function (option) {
            if (option.line && !preferredMultilineOpts_1[option.line]) {
                preferredMultilineOpts_1[option.line] = option;
            }
        });
        return Object.values(preferredMultilineOpts_1);
    }
    else {
        var preferredDefaultOpts = [];
        var _loop_1 = function (option) {
            if (preferredDefaultOpts.length >= 3) {
                return "break";
            }
            var match = option.value.match(/\d+\.\d+\./);
            if (match &&
                !preferredDefaultOpts.find(function (v) { return v.value.startsWith(match[0]); })) {
                preferredDefaultOpts.push(option);
            }
        };
        for (var _i = 0, opts_1 = opts; _i < opts_1.length; _i++) {
            var option = opts_1[_i];
            var state_1 = _loop_1(option);
            if (state_1 === "break")
                break;
        }
        return preferredDefaultOpts;
    }
};
exports.getPreferredVersionOpts = getPreferredVersionOpts;
