"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getThemeColoring = exports.getColor = exports.getColoringType = exports.darken = exports.lighten = exports.opaque = exports.isLight = exports.generateColorFromString = exports.getLegibleTextColor = void 0;
var color_1 = __importDefault(require("color"));
var color_hash_1 = __importDefault(require("color-hash"));
var find_1 = __importDefault(require("lodash/find"));
var get_1 = __importDefault(require("lodash/get"));
var memoize_1 = __importDefault(require("lodash/memoize"));
var colorHash = new color_hash_1.default();
var shadeCustomColor = function (color, shade) {
    if (shade === 'main') {
        return color;
    }
    if (shade === 'light') {
        return (0, exports.lighten)(color);
    }
    return (0, exports.darken)(color);
};
exports.getLegibleTextColor = (0, memoize_1.default)(function (bg, contrast) {
    if (contrast === void 0) { contrast = 4.5; }
    var bgColor = new color_1.default(bg);
    var findWithContrast = function (darken) {
        if (darken >= 1) {
            return bgColor.darken(1).hex();
        }
        var textColor = bgColor.darken(darken);
        if (textColor.contrast(bgColor) >= contrast) {
            return textColor.hex();
        }
        return findWithContrast(darken + 0.05);
    };
    return findWithContrast(0.1);
});
exports.generateColorFromString = (0, memoize_1.default)(function (text) {
    return colorHash.hex(text.replace(/\s/g, ''));
});
var isLight = function (color) {
    return (0, color_1.default)(color).luminosity() > 0.65;
};
exports.isLight = isLight;
var opaque = function (color, opacity) {
    return new color_1.default(__spreadArray(__spreadArray([], (0, color_1.default)(color).array(), true), [opacity], false)).string();
};
exports.opaque = opaque;
var lighten = function (color) { return (0, color_1.default)(color).fade(0.3).string(); };
exports.lighten = lighten;
var darken = function (color, amount) {
    return (0, color_1.default)(color)
        .darken(amount || 0.2)
        .string();
};
exports.darken = darken;
var getColoringType = function (props) {
    var type = (0, find_1.default)(Object.keys(props), function (b) {
        return !!props[b] && !!(0, find_1.default)(Object.keys(props.theme.colors), function (k) { return k === b; });
    });
    return type;
};
exports.getColoringType = getColoringType;
var getColor = function (props, key, shade) {
    if ((0, get_1.default)(props, key)) {
        return shadeCustomColor((0, get_1.default)(props, key), shade);
    }
    var type = (0, exports.getColoringType)(props);
    if (type) {
        var color = (0, get_1.default)(props.theme, "colors.".concat(type));
        if (color != null && typeof color === 'object') {
            return color[shade];
        }
        else {
            return shadeCustomColor(color, shade);
        }
    }
};
exports.getColor = getColor;
var getThemeColoring = function (theme, props, shade) {
    if (shade === void 0) { shade = 'main'; }
    var type = (0, find_1.default)(Object.keys(props), function (b) { return !!props[b] && !!theme.colors[b]; });
    if (type) {
        return (0, exports.getColor)(__assign(__assign({}, props), { theme: theme }), type, shade);
    }
    return '';
};
exports.getThemeColoring = getThemeColoring;
