"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var utils = __importStar(require("."));
describe('utils', function () {
    describe('.stripSchemaFormats()', function () {
        var schema = {
            type: 'object',
            properties: {
                array: {
                    type: 'array',
                    items: {
                        type: 'string',
                        format: 'dnsmasq-address',
                    },
                },
                foo: {
                    type: 'object',
                    properties: {
                        bar: {
                            type: 'string',
                            format: 'uri',
                        },
                    },
                },
                baz: {
                    type: 'string',
                    format: 'uuid',
                },
                buzz: {
                    type: 'string',
                    format: 'email',
                },
            },
        };
        it('should remove formats from a schema', function () {
            expect(utils.stripSchemaFormats(schema)).toEqual({
                type: 'object',
                properties: {
                    array: {
                        type: 'array',
                        items: {
                            type: 'string',
                        },
                    },
                    foo: {
                        type: 'object',
                        properties: {
                            bar: {
                                type: 'string',
                            },
                        },
                    },
                    baz: {
                        type: 'string',
                    },
                    buzz: {
                        type: 'string',
                    },
                },
            });
        });
        it('should allow a whitelist of formats', function () {
            var whitelist = ['email', 'uri'];
            expect(utils.stripSchemaFormats(schema, whitelist)).toEqual({
                type: 'object',
                properties: {
                    array: {
                        type: 'array',
                        items: {
                            type: 'string',
                        },
                    },
                    foo: {
                        type: 'object',
                        properties: {
                            bar: {
                                type: 'string',
                                format: 'uri',
                            },
                        },
                    },
                    baz: {
                        type: 'string',
                    },
                    buzz: {
                        type: 'string',
                        format: 'email',
                    },
                },
            });
        });
    });
    describe('.disallowAdditionalProperties()', function () {
        var schema = {
            type: 'object',
            properties: {
                foo: {
                    type: 'object',
                    properties: {
                        bar: {
                            type: 'string',
                        },
                    },
                    additionalProperties: true,
                },
            },
            additionalProperties: true,
        };
        it('should remove formats from a schema', function () {
            expect(utils.disallowAdditionalProperties(schema)).toEqual({
                type: 'object',
                properties: {
                    foo: {
                        type: 'object',
                        properties: {
                            bar: {
                                type: 'string',
                            },
                        },
                        additionalProperties: false,
                    },
                },
                additionalProperties: false,
            });
        });
        it('should not modify the original schema', function () {
            utils.disallowAdditionalProperties(schema);
            expect(schema).toEqual({
                type: 'object',
                properties: {
                    foo: {
                        type: 'object',
                        properties: {
                            bar: {
                                type: 'string',
                            },
                        },
                        additionalProperties: true,
                    },
                },
                additionalProperties: true,
            });
        });
    });
});
