import { __assign, __makeTemplateObject, __rest, __spreadArray } from "tslib";
import difference from 'lodash/difference';
import { arrayOf, number, oneOfType, string } from 'prop-types';
import * as React from 'react';
import styled, { withTheme } from 'styled-components';
import { color, display, fontSize, height, maxHeight, maxWidth, minHeight, minWidth, space, width, } from 'styled-system';
import { Tooltips } from './tooltips';
import { compose } from './utils';
export var getDisplayName = function (component) {
    if (typeof component === 'string') {
        return component;
    }
    if (!component) {
        return 'Component';
    }
    return component.displayName || component.name || 'Component';
};
var tooltip = new Tooltips();
var prop = oneOfType([number, string, arrayOf(oneOfType([number, string]))]);
var propTypes = {
    width: prop,
    minWidth: prop,
    maxWidth: prop,
    height: prop,
    minHeight: prop,
    maxHeight: prop,
    display: prop,
    fontSize: prop,
    color: prop,
    bg: prop,
    backgroundColor: prop,
    m: prop,
    mt: prop,
    mr: prop,
    mb: prop,
    ml: prop,
    mx: prop,
    my: prop,
    p: prop,
    pt: prop,
    pr: prop,
    pb: prop,
    pl: prop,
    px: prop,
    py: prop,
};
export var styledSystemProps = Object.keys(propTypes);
var filterStyledSystemProps = function (passthroughProps) { return function (Base) {
    var omitProps = difference(styledSystemProps, passthroughProps);
    return React.forwardRef(function (props, ref) {
        var nextProps = __assign({}, props);
        for (var _i = 0, omitProps_1 = omitProps; _i < omitProps_1.length; _i++) {
            var k = omitProps_1[_i];
            delete nextProps[k];
        }
        return React.createElement(Base, __assign({}, nextProps, { ref: ref }));
    });
}; };
export var withStyledSystem = function (child) {
    var Base = styled(child)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\t\t", "\n\t\t", "\n    ", "\n    ", "\n    ", "\n    ", "\n    ", "\n    ", "\n\t\t", "\n\t\t", "\n\t"], ["\n\t\t", "\n\t\t", "\n    ", "\n    ", "\n    ", "\n    ", "\n    ", "\n    ", "\n\t\t", "\n\t\t", "\n\t"])), space, width, minWidth, maxWidth, height, minHeight, maxHeight, display, fontSize, color);
    Base.displayName = getDisplayName(child);
    Base.propTypes = propTypes;
    return React.forwardRef(function (props, ref) {
        return React.createElement(Base, __assign({}, props, { ref: ref }));
    });
};
export var withTooltip = function (Base) {
    return React.forwardRef(function (_a, ref) {
        var props = __rest(_a, []);
        if (!props.tooltip) {
            return React.createElement(Base, __assign({}, props, { ref: ref }));
        }
        var tooltipProps = tooltip.bindProps(props);
        delete props.tooltip;
        return props.disabled ? (React.createElement("span", { style: { display: 'contents' }, onClick: tooltipProps.onClick, onMouseEnter: tooltipProps.onMouseEnter, onMouseLeave: tooltipProps.onMouseLeave },
            React.createElement(Base, __assign({}, props, { ref: ref })))) : (React.createElement(Base, __assign({}, tooltipProps, { ref: ref })));
    });
};
export default function asRendition(component, additionalEnhancers, passthroughProps) {
    if (additionalEnhancers === void 0) { additionalEnhancers = []; }
    if (passthroughProps === void 0) { passthroughProps = []; }
    return compose.apply(void 0, __spreadArray(__spreadArray([withTheme], (additionalEnhancers || []), false), [withTooltip,
        withStyledSystem,
        filterStyledSystemProps(passthroughProps)], false))(component);
}
var templateObject_1;
