import { __assign } from "tslib";
import get from 'lodash/get';
import { convertRefSchemeToSchemaPath, FULL_TEXT_SLUG, getModelFilter, getPropertyScheme, } from '../Filters/SchemaSieve';
import { getDataModel } from '.';
export var operators = function () { return ({
    contains: 'contains',
    not_contains: 'does not contain',
}); };
var isSchemaWithPrimitiveItems = function (schema) {
    return !!(schema === null || schema === void 0 ? void 0 : schema.items) &&
        typeof schema.items !== 'boolean' &&
        'type' in schema.items;
};
export var createFilter = function (field, operator, value, schema, _refScheme) {
    var _a;
    var filter = getFilter(field, schema, value, operator);
    if (!Object.keys(filter).length) {
        return {};
    }
    return {
        properties: (_a = {},
            _a[field] = __assign({ type: 'array' }, filter),
            _a),
        required: [field],
    };
};
export var getFilter = function (field, schema, value, operator) {
    var _a;
    if (!!(schema === null || schema === void 0 ? void 0 : schema.items) &&
        typeof schema.items !== 'boolean' &&
        'properties' in schema.items &&
        !!schema.items.properties) {
        var propertyFilters = Object.entries(schema.items.properties).map(function (_a) {
            var propKey = _a[0], propSchema = _a[1];
            return getModelFilter(propSchema, propKey, operator, value);
        });
        return {
            minItems: 1,
            contains: propertyFilters.length === 1
                ? propertyFilters[0]
                : {
                    anyOf: propertyFilters,
                },
        };
    }
    var hasPrimitiveItems = isSchemaWithPrimitiveItems(schema);
    var filterSchema = hasPrimitiveItems ? schema.items : schema;
    var innerOperator = operator.slug === FULL_TEXT_SLUG ||
        (hasPrimitiveItems && schema.items.type === 'string')
        ? operator
        : convertOperatorToIs(operator);
    var filter = getModelFilter(filterSchema, field, innerOperator, value);
    var recursiveFilter = (_a = filter.properties) === null || _a === void 0 ? void 0 : _a[field];
    var targetFilter = hasPrimitiveItems && recursiveFilter ? recursiveFilter : filter;
    if (!Object.keys(targetFilter).length) {
        return targetFilter;
    }
    if (typeof targetFilter.not === 'object') {
        return {
            not: { contains: targetFilter.not },
        };
    }
    return { minItems: 1, contains: targetFilter };
};
var convertOperatorToIs = function (operator) {
    if (operator.slug === 'not_contains') {
        return { slug: 'is_not', label: 'is not' };
    }
    if (operator.slug === 'contains') {
        return { slug: 'is', label: 'is' };
    }
    return operator;
};
export var editSchema = function (schema, operator) {
    var refScheme = getPropertyScheme(schema);
    var schemaItems = schema.items;
    var convertedRefScheme = convertRefSchemeToSchemaPath(refScheme === null || refScheme === void 0 ? void 0 : refScheme[0]);
    if (!!schemaItems && !!convertedRefScheme) {
        var property = get(schemaItems.properties, convertedRefScheme);
        return property;
    }
    var subSchema = schemaItems || schema;
    var model = getDataModel(subSchema);
    return model && 'editSchema' in model
        ? model.editSchema(subSchema, operator)
        : subSchema;
};
