import { __assign, __spreadArray } from "tslib";
import find from 'lodash/find';
import findKey from 'lodash/findKey';
import mapValues from 'lodash/mapValues';
import pick from 'lodash/pick';
import { regexEscape } from '../../utils';
import { FULL_TEXT_SLUG, getModelFilter, getPropertyScheme, } from '../Filters/SchemaSieve';
var getKeyLabel = function (schema) {
    var s = find(schema.properties, { description: 'key' });
    return s && s.title ? s.title : 'key';
};
var getValueLabel = function (schema) {
    var s = find(schema.properties, { description: 'value' });
    return s && s.title ? s.title : 'value';
};
export var isKeyValueObj = function (schema) {
    return !!find(schema.properties, { description: 'key' }) ||
        !!find(schema.properties, { description: 'value' });
};
export var operators = function (s) {
    return __assign(__assign({}, (!getPropertyScheme(s)
        ? {
            is: 'is',
            is_not: 'is not',
        }
        : {})), (!isKeyValueObj(s)
        ? {
            contains: 'contains',
            not_contains: 'does not contain',
        }
        : (function () {
            var keyLabel = getKeyLabel(s);
            var valueLabel = getValueLabel(s);
            return {
                key_contains: "".concat(keyLabel, " contains"),
                key_not_contains: "".concat(keyLabel, " does not contain"),
                key_is: "".concat(keyLabel, " is"),
                key_matches_re: "".concat(keyLabel, " matches RegEx"),
                key_not_matches_re: "".concat(keyLabel, " does not match RegEx"),
                value_is: "".concat(valueLabel, " is"),
                value_contains: "".concat(valueLabel, " contains"),
                value_not_contains: "".concat(valueLabel, " does not contain"),
                value_matches_re: "".concat(valueLabel, " matches RegEx"),
                value_not_matches_re: "".concat(valueLabel, " does not match RegEx"),
            };
        })()));
};
var keySpecificOperators = [
    'key_is',
    'key_contains',
    'key_not_contains',
    'key_matches_re',
    'key_not_matches_re',
];
var valueSpecificOperators = [
    'value_is',
    'value_contains',
    'value_not_contains',
    'value_matches_re',
    'value_not_matches_re',
];
function getValueForOperation(operator, schema, value) {
    var _a, _b;
    if (keySpecificOperators.includes(operator)) {
        var schemaKey = findKey(schema.properties, { description: 'key' });
        return typeof value === 'string'
            ? (_a = {}, _a[schemaKey] = value, _a) : pick(value, schemaKey);
    }
    if (valueSpecificOperators.includes(operator)) {
        var schemaValue = findKey(schema.properties, { description: 'value' });
        return typeof value === 'string'
            ? (_b = {}, _b[schemaValue] = value, _b) : pick(value, schemaValue);
    }
    return value;
}
var getTitleForOperation = function (operator, schema, value) {
    if (typeof value !== 'object' || !schema.properties) {
        return schema.title;
    }
    var property = schema.properties[Object.keys(value)[0]];
    if (__spreadArray(__spreadArray([], keySpecificOperators, true), valueSpecificOperators, true).includes(operator) &&
        typeof property === 'object') {
        return property.title;
    }
    return schema.title;
};
export var createFilter = function (field, operator, value, schema) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j;
    var operatorSlug = operator.slug;
    value = !!isKeyValueObj(schema)
        ? getValueForOperation(operatorSlug, schema, value)
        : value;
    var propertyTitle = getTitleForOperation(operatorSlug, schema, value);
    var isFilter = function (v) { return ({ const: v }); };
    var containsFilter = function (v) { return ({
        description: v,
        regexp: {
            pattern: regexEscape(v),
            flags: 'i',
        },
    }); };
    var matchReGexFilter = function (v) { return ({
        pattern: v,
    }); };
    if (!isKeyValueObj(schema)) {
        return {
            properties: (_a = {},
                _a[field] = getFilter(field, schema, value, operator),
                _a),
            required: [field],
        };
    }
    if (operatorSlug === FULL_TEXT_SLUG) {
        var schemaKey = findKey(schema.properties, { description: 'key' });
        var schemaValue = findKey(schema.properties, { description: 'value' });
        var properties = [schemaKey, schemaValue].map(function (key) {
            var _a;
            return ({
                properties: (_a = {},
                    _a[key] = {
                        pattern: value,
                    },
                    _a),
                required: [key],
            });
        });
        return {
            properties: (_b = {},
                _b[field] = {
                    contains: {
                        title: propertyTitle,
                        anyOf: properties,
                    },
                },
                _b),
        };
    }
    if (operatorSlug === 'is') {
        return {
            properties: (_c = {},
                _c[field] = {
                    contains: {
                        title: propertyTitle,
                        properties: mapValues(value, function (v) { return ({ const: v }); }),
                    },
                },
                _c),
            required: [field],
        };
    }
    if (operatorSlug === 'is_not') {
        return {
            properties: (_d = {},
                _d[field] = {
                    not: {
                        contains: {
                            title: propertyTitle,
                            properties: mapValues(value, function (v) { return ({ const: v }); }),
                        },
                    },
                },
                _d),
        };
    }
    if (operatorSlug === 'key_is' || operatorSlug === 'value_is') {
        return {
            properties: (_e = {},
                _e[field] = {
                    contains: {
                        title: propertyTitle,
                        properties: mapValues(value, isFilter),
                    },
                },
                _e),
            required: [field],
        };
    }
    if (operatorSlug === 'key_contains' || operatorSlug === 'value_contains') {
        return {
            properties: (_f = {},
                _f[field] = {
                    contains: {
                        title: propertyTitle,
                        properties: typeof value !== 'object'
                            ? containsFilter(value)
                            : mapValues(value, containsFilter),
                    },
                },
                _f),
            required: [field],
        };
    }
    if (operatorSlug === 'key_not_contains' ||
        operatorSlug === 'value_not_contains') {
        return {
            properties: (_g = {},
                _g[field] = {
                    not: {
                        contains: {
                            title: propertyTitle,
                            properties: typeof value !== 'object'
                                ? containsFilter(value)
                                : mapValues(value, containsFilter),
                        },
                    },
                },
                _g),
        };
    }
    if (operatorSlug === 'key_matches_re' ||
        operatorSlug === 'value_matches_re') {
        return {
            properties: (_h = {},
                _h[field] = {
                    contains: {
                        title: propertyTitle,
                        properties: typeof value !== 'object'
                            ? matchReGexFilter(value)
                            : mapValues(value, matchReGexFilter),
                    },
                },
                _h),
            required: [field],
        };
    }
    if (operatorSlug === 'key_not_matches_re' ||
        operatorSlug === 'value_not_matches_re') {
        return {
            properties: (_j = {},
                _j[field] = {
                    not: {
                        contains: {
                            title: propertyTitle,
                            properties: typeof value !== 'object'
                                ? matchReGexFilter(value)
                                : mapValues(value, matchReGexFilter),
                        },
                    },
                },
                _j),
        };
    }
    return {};
};
export var editSchema = function (schema, operator) {
    var schemaKey = findKey(schema.properties, { description: 'key' });
    var schemaValue = findKey(schema.properties, { description: 'value' });
    if (!!operator &&
        keySpecificOperators.includes(operator.slug) &&
        !!schemaKey) {
        return __assign(__assign({}, schema), { title: '', properties: pick(schema.properties, schemaKey) });
    }
    if (!!operator &&
        valueSpecificOperators.includes(operator.slug) &&
        !!schemaValue) {
        return __assign(__assign({}, schema), { title: '', properties: pick(schema.properties, schemaValue) });
    }
    return __assign(__assign({}, schema), { title: '' });
};
export var uiSchema = function (schema) {
    var _a, _b;
    if (!schema.properties || typeof schema.properties !== 'object') {
        return {};
    }
    return ((_b = (_a = Object.entries(schema.properties)) === null || _a === void 0 ? void 0 : _a.reduce(function (acc, _a) {
        var key = _a[0], value = _a[1];
        acc[key] = {
            'ui:options': {
                label: false,
                placeholder: typeof value.title === 'string' ? value.title : '',
            },
        };
        return acc;
    }, {})) !== null && _b !== void 0 ? _b : {});
};
export var getFilter = function (field, schema, value, operator) {
    var _a;
    if (!!(schema === null || schema === void 0 ? void 0 : schema.properties) && typeof schema.properties !== 'boolean') {
        return {
            anyOf: Object.entries(schema.properties).map(function (_a) {
                var propKey = _a[0], propValue = _a[1];
                var filter = getModelFilter(propValue, propKey, operator, value);
                return filter;
            }),
        };
    }
    var fieldFilter = getModelFilter(schema, field, operator, value);
    return {
        contains: (_a = fieldFilter.properties) === null || _a === void 0 ? void 0 : _a[field],
    };
};
