import { __assign, __spreadArray } from "tslib";
import React from 'react';
import { Flex } from '../Flex';
import { Modal } from '../Modal';
import { Select } from '../Select';
import debounce from 'lodash/debounce';
import { createFilter, getOperators, getSignatures, } from './SchemaSieve';
import { Txt } from '../Txt';
import { getDataModel } from '../DataTypes';
import { Form } from '../Form';
import { getPropertyScheme, getSchemaTitle, getSubSchemaFromRefScheme, } from './SchemaSieve';
import { Button } from '../Button';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faTimes } from '@fortawesome/free-solid-svg-icons/faTimes';
import { findInObject } from '../../utils';
export var FilterModal = function (_a) {
    var schema = _a.schema, editFilter = _a.editFilter, addFilter = _a.addFilter, onClose = _a.onClose;
    var properties = React.useMemo(function () {
        if (!schema.properties || typeof schema.properties === 'boolean') {
            return;
        }
        var constructedProperties = Object.entries(schema.properties).flatMap(function (_a) {
            var key = _a[0], value = _a[1];
            var refScheme = getPropertyScheme(value);
            if (!(refScheme === null || refScheme === void 0 ? void 0 : refScheme.length)) {
                return {
                    key: key,
                    field: key,
                    title: getSchemaTitle(value, key),
                };
            }
            else {
                return refScheme.map(function (ref) {
                    return {
                        key: "".concat(key, "__").concat(ref),
                        field: key,
                        title: getSchemaTitle(value, key, ref),
                        refScheme: ref,
                    };
                });
            }
        });
        return constructedProperties.sort(function (a, b) { return (a.title > b.title ? 1 : -1); });
    }, [schema]);
    var newSignature = properties
        ? {
            key: properties[0].refScheme
                ? "".concat(properties[0].field, "__").concat(properties[0].refScheme)
                : properties[0].field,
            title: properties[0].title,
            field: properties[0].field,
            operator: undefined,
            value: undefined,
            label: undefined,
            refScheme: properties[0].refScheme,
        }
        : null;
    var _b = React.useState(editFilter ? getSignatures(editFilter) : newSignature ? [newSignature] : []), signatures = _b[0], setSignatures = _b[1];
    if (!properties || !newSignature) {
        return null;
    }
    var addSignature = function (signature, index) {
        if (!signatures) {
            return;
        }
        if (!signatures.length) {
            setSignatures([__assign({}, signature)]);
        }
        else if (signatures.length >= index + 1) {
            signatures[index] = __assign({}, signature);
            setSignatures(__spreadArray([], signatures, true));
        }
        else {
            setSignatures(__spreadArray(__spreadArray([], signatures, true), [__assign({}, signature)], false));
        }
    };
    var removeSignature = function (index) {
        var newSignatures = signatures.filter(function (_f, i) { return index !== i; });
        setSignatures(newSignatures);
    };
    var isValid = function (signs) {
        return signs.every(function (s) { return s.field && s.operator && s.value != null && s.value !== ''; });
    };
    var createAndAddFilter = function () {
        if (!isValid(signatures)) {
            return;
        }
        var filter = createFilter(schema, signatures);
        return filter ? addFilter(filter) : onClose();
    };
    return (React.createElement(Modal, { title: "Filter by", cancel: onClose, done: createAndAddFilter, primaryButtonProps: {
            disabled: !isValid(signatures),
        }, action: "Save" },
        signatures.map(function (signature, index) { return (React.createElement(Flex, { flexDirection: "column", key: (signature.field || '') + index },
            index > 0 && React.createElement(Txt, { my: 2 }, "OR"),
            React.createElement(Flex, null,
                React.createElement(FilterInputs, { properties: properties, signature: signature, schema: schema, onUpdate: function (signature) { return addSignature(signature, index); } }),
                index > 0 && (React.createElement(Button, { color: "tertiary.main", ml: 2, plain: true, fontSize: 1, p: 1, onClick: function () { return removeSignature(index); } },
                    React.createElement(FontAwesomeIcon, { icon: faTimes })))))); }),
        React.createElement(Button, { mb: 2, mt: 4, primary: true, underline: true, onClick: function () { return addSignature(newSignature, signatures.length); } }, "Add alternative")));
};
var FilterInputs = function (_a) {
    var properties = _a.properties, signature = _a.signature, schema = _a.schema, onUpdate = _a.onUpdate;
    var _b = React.useState(''), searchTerm = _b[0], setSearchTerm = _b[1];
    var debouncedSetSearchTerm = debounce(setSearchTerm, 300);
    var operators = React.useMemo(function () {
        return signature.field
            ? getOperators(schema, signature.field, signature.refScheme)
            : [];
    }, [signature.field, signature.refScheme, schema]);
    var filteredFieldOptions = React.useMemo(function () {
        if (!searchTerm) {
            return properties;
        }
        var searchTermRegEx = new RegExp(searchTerm, 'i');
        return properties.filter(function (property) {
            return (property.title.match(searchTermRegEx) ||
                property.field.match(searchTermRegEx));
        });
    }, [searchTerm, properties]);
    React.useEffect(function () {
        if (signature.operator) {
            return;
        }
        onUpdate(__assign(__assign({}, signature), { operator: operators[0] }));
    }, [signature.field, operators]);
    return (React.createElement(Flex, { justifyContent: "space-between" },
        React.createElement(Select, { mr: 1, id: "filtermodal__fieldselect", options: filteredFieldOptions, onSearch: debouncedSetSearchTerm, searchPlaceholder: "Search...", valueKey: "key", labelKey: "title", value: signature, onChange: function (_a) {
                var option = _a.option;
                if (signature.field === option.field &&
                    signature.title === option.title) {
                    return;
                }
                onUpdate(__assign(__assign(__assign({}, signature), option), { operator: undefined, value: undefined, refScheme: option.refScheme }));
            } }),
        React.createElement(Select, { mr: 1, options: operators, valueKey: "slug", labelKey: "label", value: signature.operator, onChange: function (_a) {
                var _b;
                var option = _a.option;
                if (option.slug === ((_b = signature.operator) === null || _b === void 0 ? void 0 : _b.slug)) {
                    return;
                }
                onUpdate(__assign(__assign({}, signature), { operator: option }));
            } }),
        React.createElement(Flex, { maxWidth: 165 },
            React.createElement(FilterInput, { schema: schema.properties[signature.field], value: signature.value, operator: signature.operator, onUpdate: function (value) {
                    onUpdate(__assign(__assign({}, signature), { value: value }));
                }, refScheme: signature.refScheme }))));
};
var FilterInput = function (_a) {
    var _b;
    var schema = _a.schema, value = _a.value, operator = _a.operator, onUpdate = _a.onUpdate, refScheme = _a.refScheme;
    var subSchema = refScheme
        ? __assign({}, getSubSchemaFromRefScheme(schema, refScheme)) : __assign({}, schema);
    if (Array.isArray(subSchema.type)) {
        subSchema.type = subSchema.type.find(function (t) { return !!t; });
    }
    var model = getDataModel(subSchema);
    var uiSchema = model && 'uiSchema' in model ? ((_b = model.uiSchema) === null || _b === void 0 ? void 0 : _b.call(model, schema)) || {} : {};
    var newSchema = model && operator && 'editSchema' in model
        ? model.editSchema(subSchema, operator)
        : subSchema;
    var format = newSchema.format, type = newSchema.type;
    return (React.createElement(Form, { schema: __assign(__assign({}, newSchema), { type: (format === null || format === void 0 ? void 0 : format.endsWith('date-time')) ||
                findInObject(newSchema, 'maxItems') === 1
                ? 'string'
                : type }), value: value, onFormChange: function (_a) {
            var formData = _a.formData;
            return onUpdate(formData);
        }, uiSchema: __assign({ 'ui:options': { label: false, inline: true } }, uiSchema), hideSubmitButton: true }));
};
