jest.mock('lodash/debounce', function () { return jest.fn(function (fn) { return fn; }); });
import { mount } from 'enzyme';
import sinon from 'sinon';
import React from 'react';
import { Provider } from '../..';
import { FilterModal } from './FilterModal';
import { createFilter } from './SchemaSieve';
var sandbox = sinon.createSandbox();
describe('FilterModal', function () {
    var addFilter = sandbox.stub();
    var onClose = sandbox.stub();
    var schema = {
        type: 'object',
        properties: {
            name: {
                type: 'string',
            },
            type: {
                type: 'string',
            },
        },
    };
    var edit = createFilter(schema, [
        {
            title: 'Name',
            field: 'name',
            operator: { label: 'is', slug: 'is' },
            value: '',
        },
    ]);
    afterEach(function () {
        sandbox.reset();
    });
    it('lets the user search for filter fields', function () {
        var component = mount(React.createElement(Provider, null,
            React.createElement(FilterModal, { schema: schema, addFilter: addFilter, editFilter: edit, onClose: onClose })));
        var fieldSelect = component.find('Select').first();
        fieldSelect.simulate('click');
        var options = component.find('#filtermodal__fieldselect__select-drop button[role="menuitem"]');
        expect(options.length).toBe(2);
        expect(options.at(0).text()).toBe('name');
        expect(options.at(1).text()).toBe('type');
        var searchInput = component.find('input[placeholder="Search..."]');
        searchInput.simulate('change', { target: { value: 'type' } });
        options = component.find('#filtermodal__fieldselect__select-drop button[role="menuitem"]');
        expect(options.length).toBe(1);
        expect(options.at(0).text()).toBe('type');
    });
});
