import { __assign, __makeTemplateObject, __spreadArray } from "tslib";
import React from 'react';
import { Button } from '../Button';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faFilter } from '@fortawesome/free-solid-svg-icons/faFilter';
import ViewsMenu from './ViewsMenu';
import styled from 'styled-components';
import { Box } from '../Box';
import { Search } from '../Search';
import { Flex } from '../Flex';
import { FilterModal } from './FilterModal';
import { Summary } from './Summary';
import { onClickOutOrEsc, randomString } from '../../utils';
import cloneDeep from 'lodash/cloneDeep';
import isEqual from 'lodash/isEqual';
import { createFullTextSearchFilter } from './SchemaSieve';
var SearchWrapper = styled(Box)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\twidth: 100%;\n\tflex-basis: 100%;\n\tposition: relative;\n\tmargin-right: 4px;\n\tpadding: 0 4px;\n\talign-self: center;\n"], ["\n\twidth: 100%;\n\tflex-basis: 100%;\n\tposition: relative;\n\tmargin-right: 4px;\n\tpadding: 0 4px;\n\talign-self: center;\n"])));
export var Filters = function (_a) {
    var disabled = _a.disabled, filters = _a.filters, views = _a.views, schema = _a.schema, addFilterButtonProps = _a.addFilterButtonProps, viewsMenuButtonProps = _a.viewsMenuButtonProps, renderMode = _a.renderMode, dark = _a.dark, compact = _a.compact, showSaveView = _a.showSaveView, onViewsUpdate = _a.onViewsUpdate, onFiltersUpdate = _a.onFiltersUpdate, onSearch = _a.onSearch;
    var searchContainer = React.createRef();
    var _b = React.useState(false), showFilterModal = _b[0], setShowFilterModal = _b[1];
    var _c = React.useState(false), showSearchDropDown = _c[0], setShowSearchDropDown = _c[1];
    var _d = React.useState(), searchString = _d[0], setSearchString = _d[1];
    var _e = React.useState(filters !== null && filters !== void 0 ? filters : []), internalFilters = _e[0], setFilters = _e[1];
    var _f = React.useState(views), internalViews = _f[0], setViews = _f[1];
    var _g = React.useState(), editFilter = _g[0], setEditFilter = _g[1];
    React.useEffect(function () {
        if (isEqual(internalFilters, filters !== null && filters !== void 0 ? filters : [])) {
            return;
        }
        setFilters(filters !== null && filters !== void 0 ? filters : []);
    }, [filters]);
    React.useEffect(function () {
        if (isEqual(internalViews, views)) {
            return;
        }
        setViews(views);
    }, [views]);
    var deleteView = function (view) {
        if (!internalViews) {
            return;
        }
        var newViews = internalViews.filter(function (i) { return i.id !== view.id; });
        setViews(newViews);
        onViewsUpdate === null || onViewsUpdate === void 0 ? void 0 : onViewsUpdate(newViews);
    };
    var addFilter = function (filter) {
        var newFilters = internalFilters !== null && internalFilters !== void 0 ? internalFilters : [];
        if (editFilter === null || editFilter === void 0 ? void 0 : editFilter.$id) {
            newFilters = newFilters.filter(function (f) { return f.$id !== editFilter.$id; });
        }
        newFilters = __spreadArray(__spreadArray([], newFilters, true), [filter], false);
        setFilters(newFilters);
        onFiltersUpdate === null || onFiltersUpdate === void 0 ? void 0 : onFiltersUpdate(newFilters);
    };
    var deleteFilter = function (filter) {
        var _a;
        var newFilters = (_a = internalFilters === null || internalFilters === void 0 ? void 0 : internalFilters.filter(function (f) { return f.$id !== filter.$id; })) !== null && _a !== void 0 ? _a : [];
        setFilters(newFilters);
        onFiltersUpdate === null || onFiltersUpdate === void 0 ? void 0 : onFiltersUpdate(newFilters);
    };
    var saveView = function (name) {
        var _a;
        var view = {
            id: randomString(),
            name: name,
            filters: (_a = cloneDeep(filters)) !== null && _a !== void 0 ? _a : [],
        };
        var newViews = __spreadArray(__spreadArray([], (internalViews !== null && internalViews !== void 0 ? internalViews : []), true), [view], false);
        setViews(newViews);
        onViewsUpdate === null || onViewsUpdate === void 0 ? void 0 : onViewsUpdate(newViews);
    };
    return (React.createElement(Box, { style: { position: 'relative' } },
        React.createElement(Flex, { flex: "1" },
            (!renderMode || renderMode.includes('search')) && (React.createElement(SearchWrapper, { ref: searchContainer, onFocus: function () {
                    setShowSearchDropDown(true);
                    if (searchContainer.current) {
                        onClickOutOrEsc(searchContainer.current, function () {
                            setShowSearchDropDown(false);
                        });
                    }
                } },
                React.createElement(Search, { dark: dark, disabled: disabled, value: searchString, onChange: function (e) {
                        setShowSearchDropDown(e.target.value !== '');
                        setSearchString(e.target.value);
                    }, onEnter: function (e) {
                        e.preventDefault();
                        e.stopPropagation();
                        if (!searchString) {
                            return;
                        }
                        var newFilter = createFullTextSearchFilter(schema, searchString);
                        addFilter(newFilter);
                        setSearchString('');
                    } }),
                searchString && showSearchDropDown && (onSearch === null || onSearch === void 0 ? void 0 : onSearch(searchString)))),
            (!renderMode || renderMode.includes('add')) && (React.createElement(Button, __assign({ disabled: disabled, light: dark, outline: true, quartenary: true, icon: React.createElement(FontAwesomeIcon, { icon: faFilter }), onClick: function () { return setShowFilterModal(true); }, label: "Add filter", compact: compact }, addFilterButtonProps))),
            (!renderMode || renderMode.includes('views')) && (React.createElement(ViewsMenu, { dark: dark, buttonProps: viewsMenuButtonProps, disabled: disabled, views: views || [], schema: schema, renderMode: renderMode, setFilters: function (f) {
                    setFilters(f);
                    onFiltersUpdate === null || onFiltersUpdate === void 0 ? void 0 : onFiltersUpdate(f);
                }, deleteView: deleteView, compact: compact }))),
        (!renderMode || renderMode.includes('summary')) &&
            internalFilters.length > 0 &&
            !disabled && (React.createElement(Summary, { onEdit: function (filter) {
                setEditFilter(filter);
                setShowFilterModal(true);
            }, onDelete: deleteFilter, onClearFilters: function () {
                setFilters([]);
                onFiltersUpdate === null || onFiltersUpdate === void 0 ? void 0 : onFiltersUpdate([]);
            }, showSaveView: showSaveView !== null && showSaveView !== void 0 ? showSaveView : renderMode === null || renderMode === void 0 ? void 0 : renderMode.includes('views'), onSaveView: function (_a) {
                var name = _a.name;
                return saveView(name);
            }, filters: internalFilters })),
        showFilterModal && (React.createElement(FilterModal, { schema: schema, editFilter: editFilter, addFilter: function (filter) {
                addFilter(filter);
                setShowFilterModal(false);
            }, onClose: function () { return setShowFilterModal(false); } }))));
};
var templateObject_1;
