import { __assign, __makeTemplateObject, __rest, __spreadArray } from "tslib";
import uniqBy from 'lodash/uniqBy';
import * as React from 'react';
import RsjfForm from '@rjsf/core';
import styled from 'styled-components';
import { Box } from '../Box';
import { Button } from '../Button';
import * as utils from '../../utils';
import { DescriptionField } from './fields/DescriptionField';
import ObjectField from './fields/ObjectField';
import { TitleField } from './fields/TitleField';
import ArrayFieldTemplate from './templates/ArrayFieldTemplate';
import FieldTemplate from './templates/FieldTemplate';
import ObjectFieldTemplate from './templates/ObjectFieldTemplate';
import BaseInput from './widgets/BaseInput';
import PasswordWidget from './widgets/PasswordWidget';
import SelectWidget from './widgets/SelectWidget';
import TextareaWidget from './widgets/TextareaWidget';
import { WidgetContext } from '../../contexts/WidgetContext';
var SUPPORTED_SCHEMA_FORMATS = [
    'data-url',
    'date',
    'date-time',
    'email',
    'hostname',
    'ipv4',
    'ipv6',
    'uri',
];
var internalWidgets = {
    BaseInput: BaseInput,
    SelectWidget: SelectWidget,
    PasswordWidget: PasswordWidget,
    TextareaWidget: TextareaWidget,
};
var fields = {
    DescriptionField: DescriptionField,
    ObjectField: ObjectField,
    TitleField: TitleField,
};
var FormWrapper = styled(Box)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tsection {\n\t\tmargin: 0;\n\t\tpadding: 0;\n\t\tborder: 0;\n\t}\n\n\tlabel {\n\t\tfont-size: ", ";\n\t}\n\n\tinput {\n\t\tfont-size: ", ";\n\t}\n\n\t/* Style the error list, since it can't be templated */\n\t.panel-danger,\n\t.error-detail {\n\t\tfont-size: ", ";\n\t\tmargin-top: ", ";\n\t\tmargin-bottom: ", ";\n\t\tlist-style-type: none;\n\t\tpadding-left: 0;\n\t}\n\n\t.text-danger {\n\t\tcolor: ", ";\n\t}\n\n\tinput[type='file'] {\n\t\tcursor: pointer;\n\t\t&::file-selector-button {\n\t\t\tcursor: pointer;\n\t\t\tfont-weight: ", ";\n\t\t\tfont-size: ", ";\n\t\t\theight: ", ";\n\t\t\tborder-color: ", ";\n\t\t\tbackground: ", ";\n\t\t\twhite-space: nowrap;\n\t\t\tdisplay: inline-flex;\n\t\t\talign-items: center;\n\t\t\tjustify-content: center;\n\t\t\tcolor: white;\n\t\t\tpadding: 4px 20px;\n\t\t\tborder-radius: 20px;\n\t\t\tborder: 1px solid ", ";\n\n\t\t\t&:disabled {\n\t\t\t\tcursor: not-allowed;\n\t\t\t}\n\t\t\t&:hover {\n\t\t\t\tbox-shadow: none;\n\t\t\t\tbackground: ", ";\n\t\t\t\tborder-color: ", ";\n\t\t\t}\n\t\t}\n\t}\n"], ["\n\tsection {\n\t\tmargin: 0;\n\t\tpadding: 0;\n\t\tborder: 0;\n\t}\n\n\tlabel {\n\t\tfont-size: ", ";\n\t}\n\n\tinput {\n\t\tfont-size: ", ";\n\t}\n\n\t/* Style the error list, since it can't be templated */\n\t.panel-danger,\n\t.error-detail {\n\t\tfont-size: ", ";\n\t\tmargin-top: ", ";\n\t\tmargin-bottom: ", ";\n\t\tlist-style-type: none;\n\t\tpadding-left: 0;\n\t}\n\n\t.text-danger {\n\t\tcolor: ", ";\n\t}\n\n\tinput[type='file'] {\n\t\tcursor: pointer;\n\t\t&::file-selector-button {\n\t\t\tcursor: pointer;\n\t\t\tfont-weight: ", ";\n\t\t\tfont-size: ", ";\n\t\t\theight: ", ";\n\t\t\tborder-color: ", ";\n\t\t\tbackground: ", ";\n\t\t\twhite-space: nowrap;\n\t\t\tdisplay: inline-flex;\n\t\t\talign-items: center;\n\t\t\tjustify-content: center;\n\t\t\tcolor: white;\n\t\t\tpadding: 4px 20px;\n\t\t\tborder-radius: 20px;\n\t\t\tborder: 1px solid ", ";\n\n\t\t\t&:disabled {\n\t\t\t\tcursor: not-allowed;\n\t\t\t}\n\t\t\t&:hover {\n\t\t\t\tbox-shadow: none;\n\t\t\t\tbackground: ", ";\n\t\t\t\tborder-color: ", ";\n\t\t\t}\n\t\t}\n\t}\n"])), function (props) { var _a; return utils.px((_a = props === null || props === void 0 ? void 0 : props.theme) === null || _a === void 0 ? void 0 : _a.fontSizes[1]); }, function (props) { var _a; return utils.px((_a = props === null || props === void 0 ? void 0 : props.theme) === null || _a === void 0 ? void 0 : _a.fontSizes[2]); }, function (props) { var _a, _b, _c; return utils.px((_c = (_b = (_a = props === null || props === void 0 ? void 0 : props.theme) === null || _a === void 0 ? void 0 : _a.fontSizes) === null || _b === void 0 ? void 0 : _b[1]) !== null && _c !== void 0 ? _c : 14); }, function (props) { var _a, _b, _c; return utils.px((_c = (_b = (_a = props === null || props === void 0 ? void 0 : props.theme) === null || _a === void 0 ? void 0 : _a.space) === null || _b === void 0 ? void 0 : _b[1]) !== null && _c !== void 0 ? _c : 4); }, function (props) { var _a, _b, _c; return utils.px((_c = (_b = (_a = props === null || props === void 0 ? void 0 : props.theme) === null || _a === void 0 ? void 0 : _a.space) === null || _b === void 0 ? void 0 : _b[1]) !== null && _c !== void 0 ? _c : 4); }, function (props) { var _a, _b, _c, _d; return (_d = (_c = (_b = (_a = props === null || props === void 0 ? void 0 : props.theme) === null || _a === void 0 ? void 0 : _a.colors) === null || _b === void 0 ? void 0 : _b.danger) === null || _c === void 0 ? void 0 : _c.main) !== null && _d !== void 0 ? _d : '#a94442'; }, function (props) { return props.theme.button.font.weight; }, function (props) { return props.theme.button.font.size; }, function (props) { return props.theme.button.height; }, function (props) { return props.theme.colors.primary.main; }, function (props) { return props.theme.colors.primary.main; }, function (props) { return props.theme.colors.primary.main; }, function (props) { return props.theme.colors.primary.dark; }, function (props) { return props.theme.colors.primary.dark; });
var parseSchema = function (schema) {
    var whitelist = SUPPORTED_SCHEMA_FORMATS.concat(Object.keys(internalWidgets));
    return utils.stripSchemaFormats(schema, whitelist);
};
var BaseForm = React.forwardRef(function (_a, ref) {
    var _b;
    var schema = _a.schema, value = _a.value, disabled = _a.disabled, extraFormats = _a.extraFormats, onFormChange = _a.onFormChange, onFormSubmit = _a.onFormSubmit, hideSubmitButton = _a.hideSubmitButton, submitButtonText = _a.submitButtonText, submitButtonProps = _a.submitButtonProps, secondaryButtonProps = _a.secondaryButtonProps, uiSchema = _a.uiSchema, validate = _a.validate, liveValidate = _a.liveValidate, noValidate = _a.noValidate, transformErrors = _a.transformErrors, widgets = _a.widgets, props = __rest(_a, ["schema", "value", "disabled", "extraFormats", "onFormChange", "onFormSubmit", "hideSubmitButton", "submitButtonText", "submitButtonProps", "secondaryButtonProps", "uiSchema", "validate", "liveValidate", "noValidate", "transformErrors", "widgets"]);
    var form = React.useContext(WidgetContext).form;
    var contextFormats = (_b = form === null || form === void 0 ? void 0 : form.formats) !== null && _b !== void 0 ? _b : [];
    var allWidgets = React.useMemo(function () {
        return __assign(__assign(__assign({}, internalWidgets), uniqBy(__spreadArray(__spreadArray([], (extraFormats !== null && extraFormats !== void 0 ? extraFormats : []), true), contextFormats, true), function (format) { return format.name; }).reduce(function (agg, format) {
            if (format.widget) {
                agg[format.name] = format.widget;
            }
            return agg;
        }, {})), widgets);
    }, [internalWidgets, extraFormats]);
    internalWidgets = allWidgets;
    var calculatedSchema = React.useMemo(function () {
        var parsedSchema = parseSchema(schema);
        var _a = utils.disallowAdditionalProperties(parsedSchema), $schema = _a.$schema, resultingSchema = __rest(_a, ["$schema"]);
        return resultingSchema;
    }, [schema]);
    var _c = React.useState(value), formState = _c[0], setFormState = _c[1];
    React.useEffect(function () {
        setFormState(value);
    }, [value]);
    var handleKeyUpDown = React.useCallback(function (e) {
        if (e.key === 'Enter' && !hideSubmitButton) {
            e.stopPropagation();
        }
    }, [hideSubmitButton]);
    var change = React.useCallback(function (data) {
        setFormState(data.formData);
        if (onFormChange) {
            onFormChange(data);
        }
    }, [onFormChange]);
    return (React.createElement(FormWrapper, __assign({}, props, { onKeyDown: handleKeyUpDown, onKeyUp: handleKeyUpDown }),
        React.createElement(RsjfForm, { ref: ref, disabled: disabled, liveValidate: liveValidate, noValidate: noValidate, validate: validate, transformErrors: transformErrors, showErrorList: false, schema: calculatedSchema, formData: formState, onSubmit: onFormSubmit, onChange: change, uiSchema: uiSchema, widgets: allWidgets, fields: fields, FieldTemplate: FieldTemplate, ObjectFieldTemplate: ObjectFieldTemplate, ArrayFieldTemplate: ArrayFieldTemplate },
            hideSubmitButton && React.createElement("span", null),
            !hideSubmitButton && (React.createElement(Button, __assign({ primary: true }, submitButtonProps, { type: "submit" }), submitButtonText || 'Submit')),
            !!secondaryButtonProps && (React.createElement(Button, __assign({ outline: true, secondary: true, ml: 3 }, secondaryButtonProps))))));
});
export var Form = BaseForm;
var templateObject_1;
