import { mount } from 'enzyme';
import React from 'react';
import sinon from 'sinon';
import { Modal, Provider } from '../../';
var ESCAPE_KEY = 27;
var ENTER_KEY = 13;
describe('Keyboard closing modals', function () {
    it('should call the callback of the top-most nested modal on Escape key press', function () {
        var firstModalSpy = sinon.spy();
        var secondModalSpy = sinon.spy();
        var component = mount(React.createElement(Provider, null,
            React.createElement(Modal, { done: firstModalSpy },
                React.createElement(Modal, { done: secondModalSpy }, "Test"))));
        component
            .find('div[onKeyDown]')
            .forEach(function (node) { return node.simulate('keydown', { which: ESCAPE_KEY }); });
        expect(firstModalSpy.notCalled).toBeTruthy();
        expect(secondModalSpy.calledOnce).toBeTruthy();
    });
    it('should call the callback of the only modal on Escape key press', function () {
        var modalSpy = sinon.spy();
        var component = mount(React.createElement(Provider, null,
            React.createElement(Modal, { done: modalSpy }, "Test")));
        component
            .find('div[onKeyDown]')
            .forEach(function (node) { return node.simulate('keydown', { which: ESCAPE_KEY }); });
        expect(modalSpy.calledOnce).toBeTruthy();
    });
});
describe('Keyboard submitting nested modals', function () {
    var originalAddEventListener;
    var eventListenersMap = {};
    beforeAll(function () {
        originalAddEventListener = window.addEventListener;
        window.addEventListener = function (event, cb) {
            if (!eventListenersMap[event]) {
                eventListenersMap[event] = [];
            }
            eventListenersMap[event].push(cb);
        };
    });
    afterAll(function () {
        window.addEventListener = originalAddEventListener;
    });
    it('should call the callback of the top-most modal with done on Enter key press', function () {
        var firstModalSpy = sinon.spy();
        var secondModalSpy = sinon.spy();
        mount(React.createElement(Provider, null,
            React.createElement(Modal, { done: firstModalSpy },
                React.createElement(Modal, { done: secondModalSpy }, "Test"))));
        eventListenersMap.keydown.forEach(function (fn) {
            return fn({
                preventDefault: function () { return null; },
                stopPropagation: function () { return null; },
                which: ENTER_KEY,
            });
        });
        expect(firstModalSpy.notCalled).toBeTruthy();
        expect(secondModalSpy.calledOnce).toBeTruthy();
    });
    it('should not call any callback of either modal on Enter key press when the primary button is disabled', function () {
        var firstModalSpy = sinon.spy();
        var secondModalSpy = sinon.spy();
        mount(React.createElement(Provider, null,
            React.createElement(Modal, { done: firstModalSpy },
                React.createElement(Modal, { primaryButtonProps: { disabled: true }, done: secondModalSpy }, "Test"))));
        eventListenersMap.keydown.forEach(function (fn) {
            return fn({
                preventDefault: function () { return null; },
                stopPropagation: function () { return null; },
                which: ENTER_KEY,
            });
        });
        expect(firstModalSpy.notCalled).toBeTruthy();
        expect(secondModalSpy.notCalled).toBeTruthy();
    });
});
