import { __awaiter, __generator } from "tslib";
import { mount } from 'enzyme';
import React from 'react';
import sinon from 'sinon';
import { Button, Provider, NotificationsContainer, notifications, } from '../../';
var NotificationsComponent = function (_a) {
    var content = _a.content, idToRemove = _a.idToRemove;
    return (React.createElement(Provider, null,
        React.createElement(NotificationsContainer, null),
        React.createElement(Button, { onClick: function () { return notifications.addNotification(content); } }, "Add text notification"),
        React.createElement(Button, { onClick: function () { return notifications.removeNotification(idToRemove); } }, "Remove text notification")));
};
describe('Notifications component', function () {
    it('can add a notification', function () {
        var component = mount(React.createElement(NotificationsComponent, { content: 'A notification' }));
        component.find('button').first().simulate('click');
        expect(component.find('.rnc__notification-item').text()).toBe('A notification');
    });
    it('can remove a notification using the API', function () {
        var id = 'notification-id';
        var component = mount(React.createElement(NotificationsComponent, { content: { content: 'A notification', id: id }, idToRemove: id }));
        component.find('button').first().simulate('click');
        component.find('button').at(2).simulate('click');
        component.find('.rnc__notification-item').first().simulate('transitionend');
        expect(component.find('.rnc__notification-item')).toHaveLength(0);
    });
    it('can remove a notification by clicking on the dismiss button', function () {
        var component = mount(React.createElement(NotificationsComponent, { content: 'A notification' }));
        component.find('button').first().simulate('click');
        component
            .find('.rnc__notification-item')
            .find('button')
            .first()
            .simulate('click');
        component.find('.rnc__notification-item').first().simulate('transitionend');
        expect(component.find('.rnc__notification-item')).toHaveLength(0);
    });
    it('calls the onDismiss callback when the dismiss button is clicked', function () {
        var callback = sinon.spy();
        var component = mount(React.createElement(NotificationsComponent, { content: { content: 'A notification', onDismiss: callback } }));
        component.find('button').first().simulate('click');
        component
            .find('.rnc__notification-item')
            .find('button')
            .first()
            .simulate('click');
        expect(callback.callCount).toEqual(1);
    });
    it('disappears after the duration passes', function () { return __awaiter(void 0, void 0, void 0, function () {
        var component;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    component = mount(React.createElement(NotificationsComponent, { content: { content: 'A notification', duration: 20 } }));
                    component.find('button').first().simulate('click');
                    component.find('.rnc__notification-item').first().simulate('transitionend');
                    return [4, new Promise(function (r) { return setTimeout(r, 200); })];
                case 1:
                    _a.sent();
                    component.find('.rnc__notification-item').first().simulate('transitionend');
                    expect(component.find('.rnc__notification-item')).toHaveLength(0);
                    return [2];
            }
        });
    }); });
    it('displays notifications in the expected position', function () {
        var container = 'bottom-right';
        var component = mount(React.createElement(NotificationsComponent, { content: {
                container: container,
                content: 'A notification',
            } }));
        component.find('button').first().simulate('click');
        expect(component.find(".rnc__notification-container--".concat(container)).text()).toBe('A notification');
    });
});
