import { __assign, __rest, __spreadArray } from "tslib";
import * as React from 'react';
import castArray from 'lodash/castArray';
import forEach from 'lodash/forEach';
import uniqBy from 'lodash/uniqBy';
import keys from 'lodash/keys';
import pick from 'lodash/pick';
import toPath from 'lodash/toPath';
import isArray from 'lodash/isArray';
import ajv from 'ajv';
import asRendition from '../../asRendition';
import { Flex } from '../Flex';
import { Alert } from '../Alert';
import { defaultFormats, typeWidgets, WidgetWrapperUiOptions, WidgetMeta, } from './widgets';
import { transformUiSchema, getBestSchemaMatch } from './widgets/widget-util';
import { JsonTypes } from './types';
import { WidgetContext } from '../../contexts/WidgetContext';
export { widgetFactory } from './widgets/widget-util';
export var getValue = function (value, schema, uiSchema) {
    var calculatedValue = uiSchema === null || uiSchema === void 0 ? void 0 : uiSchema['ui:value'];
    return calculatedValue !== undefined
        ? calculatedValue
        : value !== undefined
            ? value
            : schema === null || schema === void 0 ? void 0 : schema.default;
};
var widgetWrapperUiOptionKeyPaths = keys(WidgetWrapperUiOptions).map(toPath);
export var getType = function (value) {
    if (value === undefined) {
        return 'default';
    }
    if (value === null) {
        return 'null';
    }
    return isArray(value) ? 'array' : typeof value;
};
export var getWidget = function (value, format, uiSchemaWidget, extraFormats) {
    var _a, _b;
    var valueType = getType(value);
    var extraFormat = extraFormats === null || extraFormats === void 0 ? void 0 : extraFormats.find(function (extraFormat) {
        var _a, _b;
        return (extraFormat.name === format || extraFormat.name === uiSchemaWidget) &&
            ((_b = (_a = extraFormat.widget) === null || _a === void 0 ? void 0 : _a.supportedTypes) === null || _b === void 0 ? void 0 : _b.includes(valueType));
    });
    return (_b = (_a = extraFormat === null || extraFormat === void 0 ? void 0 : extraFormat.widget) !== null && _a !== void 0 ? _a : typeWidgets[valueType]) !== null && _b !== void 0 ? _b : typeWidgets.default;
};
var buildValidation = function (schema, extraFormats) {
    var validator = new ajv();
    forEach(extraFormats, function (_a) {
        var name = _a.name, format = _a.format;
        validator.addFormat(name, format);
    });
    return {
        validator: validator,
        validate: validator.compile(schema || {}),
    };
};
var RendererBase = function (_a) {
    var _b;
    var value = _a.value, schema = _a.schema, uiSchema = _a.uiSchema, valueKey = _a.valueKey, extraFormats = _a.extraFormats, extraContext = _a.extraContext, validate = _a.validate, nested = _a.nested, props = __rest(_a, ["value", "schema", "uiSchema", "valueKey", "extraFormats", "extraContext", "validate", "nested"]);
    var renderer = React.useContext(WidgetContext).renderer;
    var processedSchema = React.useMemo(function () {
        return getBestSchemaMatch(schema, value);
    }, [schema, value]);
    var formats = React.useMemo(function () {
        var _a;
        return uniqBy(__spreadArray(__spreadArray(__spreadArray([], (extraFormats !== null && extraFormats !== void 0 ? extraFormats : []), true), ((_a = renderer === null || renderer === void 0 ? void 0 : renderer.formats) !== null && _a !== void 0 ? _a : []), true), defaultFormats, true), function (format) { return format.name; });
    }, [renderer === null || renderer === void 0 ? void 0 : renderer.formats, extraFormats, defaultFormats]);
    var _c = React.useState(validate && !nested ? buildValidation(processedSchema, formats) : null), validation = _c[0], setValidation = _c[1];
    var _d = React.useState(null), validationErrors = _d[0], setValidationErrors = _d[1];
    React.useEffect(function () {
        if (!validate || nested) {
            setValidationErrors(null);
            return;
        }
        setValidation(buildValidation(processedSchema, formats));
    }, [validate, nested, formats, processedSchema]);
    React.useEffect(function () {
        if (!validate || nested) {
            return;
        }
        var v = validation;
        if (!v) {
            v = buildValidation(processedSchema, formats);
            setValidation(v);
        }
        v.validate(value);
        setValidationErrors(v.validate.errors);
    }, [validate, nested, validation, value, processedSchema]);
    if (uiSchema === null) {
        return null;
    }
    var processedUiSchema = transformUiSchema({
        value: value,
        uiSchema: uiSchema,
        extraContext: extraContext,
    });
    var processedValue = getValue(value, processedSchema, processedUiSchema);
    var types = (processedSchema === null || processedSchema === void 0 ? void 0 : processedSchema.type) != null ? castArray(processedSchema.type) : [];
    if (processedValue === undefined ||
        (processedValue === null && !types.includes(JsonTypes.null))) {
        return null;
    }
    var wrapperProps = pick((_b = processedUiSchema['ui:options']) !== null && _b !== void 0 ? _b : {}, widgetWrapperUiOptionKeyPaths);
    var Widget = getWidget(processedValue, processedSchema === null || processedSchema === void 0 ? void 0 : processedSchema.format, processedUiSchema['ui:widget'], formats);
    return (React.createElement(Flex, __assign({ minWidth: 0, minHeight: 0, alignItems: "flex-start", mb: 1, flexDirection: "column" }, props, wrapperProps),
        validationErrors && (React.createElement(Alert, { my: 2, plaintext: true, danger: true, tooltip: validation === null || validation === void 0 ? void 0 : validation.validator.errorsText(validationErrors) }, "Invalid data/schema")),
        React.createElement(WidgetMeta, { schema: processedSchema, uiSchema: processedUiSchema, valueKey: valueKey }),
        React.createElement(Widget, { extraContext: extraContext, extraFormats: formats, value: processedValue, schema: processedSchema, uiSchema: processedUiSchema })));
};
var RenditionRendererBase = asRendition(RendererBase);
export var Renderer = function (props) {
    return React.createElement(RenditionRendererBase, __assign({}, props));
};
