import { __assign, __rest } from "tslib";
import * as React from 'react';
import isArray from 'lodash/isArray';
import get from 'lodash/get';
import map from 'lodash/map';
import { ButtonGroup } from '../../ButtonGroup';
import { widgetFactory, getArrayItems, withOptionProps } from './widget-util';
import { JsonTypes } from '../types';
import ButtonWidget from './ButtonWidget';
var validItemTypes = ['string', 'integer', 'number'];
var WrappedButtonWidget = ButtonWidget.uiOptions
    ? withOptionProps(ButtonWidget.uiOptions)(ButtonWidget)
    : ButtonWidget;
var ButtonGroupWidget = widgetFactory('ButtonGroup', {}, [JsonTypes.array])(function (_a) {
    var value = _a.value, schema = _a.schema, uiSchema = _a.uiSchema, extraContext = _a.extraContext, extraFormats = _a.extraFormats, props = __rest(_a, ["value", "schema", "uiSchema", "extraContext", "extraFormats"]);
    if (!isArray(value)) {
        throw new Error("ButtonGroupWidget cannot be used to render a value of type '".concat(typeof value, "'"));
    }
    var itemType = get(schema, ['items', 'type'], 'undefined');
    if (!validItemTypes.includes(itemType)) {
        throw new Error("ButtonGroupWidget cannot be used to render an array of items of type ".concat(itemType));
    }
    var items = getArrayItems({ value: value, schema: schema, uiSchema: uiSchema, extraContext: extraContext });
    return (React.createElement(ButtonGroup, __assign({}, props), map(items, function (item, index) { return (React.createElement(WrappedButtonWidget, __assign({ key: index }, item, { extraFormats: extraFormats }))); })));
});
export default ButtonGroupWidget;
