import { __assign, __rest } from "tslib";
import * as React from 'react';
import isArray from 'lodash/isArray';
import get from 'lodash/get';
import map from 'lodash/map';
import { DropDownButton } from '../../DropDownButton';
import { widgetFactory, getArrayItems } from './widget-util';
import { JsonTypes } from '../types';
import { UiOption } from './ui-options';
import { Renderer } from '../index';
var validItemTypes = ['string', 'integer', 'number'];
var DropDownButtonWidget = widgetFactory('DropDownButton', {
    label: UiOption.string,
    disabled: UiOption.boolean,
    primary: UiOption.boolean,
    secondary: UiOption.boolean,
    tertiary: UiOption.boolean,
    quarternary: UiOption.boolean,
    danger: UiOption.boolean,
    warning: UiOption.boolean,
    success: UiOption.boolean,
    info: UiOption.boolean,
    emphasized: UiOption.boolean,
    square: UiOption.boolean,
    border: UiOption.boolean,
    joined: UiOption.boolean,
    alignRight: UiOption.boolean,
    listMaxHeight: UiOption.space,
}, [JsonTypes.array])(function (_a) {
    var value = _a.value, schema = _a.schema, uiSchema = _a.uiSchema, extraContext = _a.extraContext, extraFormats = _a.extraFormats, props = __rest(_a, ["value", "schema", "uiSchema", "extraContext", "extraFormats"]);
    if (!isArray(value)) {
        throw new Error("DropDownButtonWidget cannot be used to render a value of type '".concat(typeof value, "'"));
    }
    var itemType = get(schema, ['items', 'type'], 'undefined');
    if (!validItemTypes.includes(itemType)) {
        throw new Error("DropDownButtonWidget cannot be used to render an array of items of type ".concat(itemType));
    }
    var items = getArrayItems({ value: value, schema: schema, uiSchema: uiSchema, extraContext: extraContext });
    return (React.createElement(DropDownButton, __assign({}, props), map(items, function (item, index) { return (React.createElement(Renderer, __assign({ key: index }, item, { extraFormats: extraFormats }))); })));
});
export default DropDownButtonWidget;
