import { __assign, __spreadArray } from "tslib";
import * as React from 'react';
import { format, formatDistance } from 'date-fns';
import skhema from 'skhema';
import jsone from 'json-e';
import merge from 'lodash/merge';
import pickBy from 'lodash/pickBy';
import difference from 'lodash/difference';
import isArray from 'lodash/isArray';
import keys from 'lodash/keys';
import has from 'lodash/has';
import get from 'lodash/get';
import pick from 'lodash/pick';
export function widgetFactory(displayName, uiOptions, supportedTypes) {
    return function (widgetFn) {
        var widget = widgetFn;
        Object.assign(widget, {
            displayName: displayName,
            uiOptions: uiOptions,
            supportedTypes: supportedTypes,
        });
        return widget;
    };
}
var DATE_FORMAT = 'MMM do yyyy';
var TIME_FORMAT = 'h:mm a';
export function formatTimestamp(timestamp, uiSchema) {
    if (uiSchema === void 0) { uiSchema = {}; }
    if (!timestamp) {
        return '';
    }
    var uiFormat = get(uiSchema, ['ui:options', 'dtFormat']) ||
        "".concat(DATE_FORMAT, ", ").concat(TIME_FORMAT);
    return format(new Date(timestamp), uiFormat);
}
export var timeSince = function (timestamp, suffix) {
    if (suffix === void 0) { suffix = true; }
    return formatDistance(new Date(timestamp), new Date(), { addSuffix: suffix });
};
export function withOptionProps(uiOptions) {
    return function (Component) {
        var wrapped = function (props) {
            var extraProps = pick.apply(void 0, __spreadArray([get(props.uiSchema, 'ui:options', {})], keys(uiOptions), false));
            return React.createElement(Component, __assign({}, props, extraProps));
        };
        wrapped.displayName = Component.displayName;
        wrapped.uiOptions = Component.uiOptions;
        wrapped.supportedTypes = Component.supportedTypes;
        return wrapped;
    };
}
export var transformUiSchema = function (_a) {
    var value = _a.value, uiSchema = _a.uiSchema, extraContext = _a.extraContext;
    if (uiSchema == null) {
        return {};
    }
    var context = __assign({ source: value !== null && value !== void 0 ? value : '' }, extraContext);
    if (typeof value === 'object') {
        var trimmedUiSchema = pickBy(uiSchema, function (_, k) { return k.startsWith('ui:'); });
        var processedUiSchema = jsone(trimmedUiSchema, context);
        return merge({}, uiSchema, processedUiSchema);
    }
    return jsone(uiSchema, context);
};
export var getBestSchemaMatch = function (schema, value) {
    if (!(schema === null || schema === void 0 ? void 0 : schema.anyOf)) {
        return schema;
    }
    var mostRelevantSchema = schema.anyOf.reduce(function (mostRelevantSchema, anyOfItem) {
        var match = skhema.match(anyOfItem, value);
        if (match.valid && match.score > mostRelevantSchema.score) {
            return {
                schema: anyOfItem,
                score: match.score,
            };
        }
        return mostRelevantSchema;
    }, {
        schema: schema,
        score: 0,
    });
    return mostRelevantSchema.schema;
};
export var getArrayItems = function (_a) {
    var value = _a.value, schema = _a.schema, uiSchema = _a.uiSchema, extraContext = _a.extraContext, extraFormats = _a.extraFormats;
    if (!isArray(value)) {
        throw new Error("Value must be an array (not '".concat(typeof value, "')"));
    }
    var maxItems = get(uiSchema, ['ui:options', 'truncate'], value.length);
    var items = value.slice(0, maxItems).map(function (item) {
        var itemSchema = get(schema, 'items', {});
        var itemUiSchema = get(uiSchema, 'items', {});
        var processedUiSchema = transformUiSchema({
            value: item,
            uiSchema: itemUiSchema,
            extraContext: extraContext,
        });
        return {
            value: item,
            schema: itemSchema,
            uiSchema: processedUiSchema,
            extraContext: extraContext,
            extraFormats: extraFormats,
        };
    });
    if (maxItems < value.length) {
        items.push({
            value: "+ ".concat(value.length - maxItems, " more"),
            schema: {
                type: 'string',
            },
            uiSchema: {},
            extraContext: extraContext,
            extraFormats: extraFormats,
        });
    }
    return items;
};
var getMaterializedPropertyNames = function (uiSchema) {
    return keys(uiSchema).filter(function (uiSchemaKey) {
        return uiSchemaKey.startsWith('ui:field:');
    });
};
export function getObjectPropertyNames(_a) {
    var value = _a.value, schema = _a.schema, uiSchema = _a.uiSchema;
    if (typeof value !== 'object') {
        throw new Error("Cannot get object property names from a value of type '".concat(typeof value, "'"));
    }
    var uiSchemaPropertyNames = getMaterializedPropertyNames(uiSchema);
    var schemaPropertyNames = get(uiSchema, ['ui:order'], keys(get(schema, 'properties'))) || [];
    var nonSchemaPropertyNames = difference(keys(value) || [], schemaPropertyNames);
    var allObjectPropertyNames = __spreadArray(__spreadArray(__spreadArray([], uiSchemaPropertyNames, true), schemaPropertyNames, true), nonSchemaPropertyNames, true);
    return get(uiSchema, 'ui:explicit', false)
        ? allObjectPropertyNames.filter(function (propName) { return has(uiSchema, propName); })
        : allObjectPropertyNames;
}
export var truncateHash = function (str, maxLength) {
    if (maxLength === void 0) { maxLength = 7; }
    if (!str || str.length < maxLength) {
        return str;
    }
    return str.substring(0, maxLength);
};
