import * as React from 'react';
import { TableBaseProps, TableSortOptions, Pagination, CheckedState } from './TableBase';
import { TableColumnState } from './TableColumnSelector';
import { TableBaseColumn, TableRow, TableSortFunction } from './TableRow';
export declare const TableColumnSelectorSizer: import("styled-components").StyledComponent<"div", any, {
    pagerPosition: 'top' | 'bottom' | 'both' | undefined;
}, never>;
export interface TableColumn<T> extends TableBaseColumn<T> {
    title?: string;
    selected?: boolean;
    locked?: boolean;
}
type TableColumnInternal<T> = TableBaseColumn<T> & TableColumnState;
export interface TableProps<T> extends TableBaseProps<T> {
    data: T[];
    columns: Array<TableColumn<T>>;
    tagField?: Extract<keyof T, string>;
    innerRef?: React.LegacyRef<React.Component<TableProps<T> & {
        enableCustomColumns?: boolean | undefined;
    }, {}, any>>;
    columnStateRestorationKey?: string;
    sortingStateRestorationKey?: string;
    loadColumnPreferences?: () => TableColumnState[] | undefined;
    saveColumnPreferences?: (newColumns: TableColumnState[]) => void;
    enableCustomColumns?: boolean;
}
interface TableWithCustomColumnsState<T> {
    allColumns: Array<TableColumnInternal<T>>;
    visibleColumns: Array<TableColumnInternal<T>>;
    tagKeys: string[];
    selectedTagColumnKeys: string[];
    newTagColumnKeys: string[];
    sort: TableSortOptions<T> | undefined;
}
export declare class Table<T extends {}> extends React.Component<TableProps<T>, TableWithCustomColumnsState<T>> {
    constructor(props: TableProps<T>);
    componentWillReceiveProps(newProps: TableProps<T>): void;
    protected getTagKeys(columns: Array<TableColumnInternal<T>>, data: T[]): {
        tagKeys: string[];
        selectedTagColumnKeys: string[];
        newTagColumnKeys: string[];
    };
    protected getNewStateSlice(columns: Array<TableColumnInternal<T>>, data: T[]): TableWithCustomColumnsState<T>;
    protected setColumns(newColumns: Array<TableColumnInternal<T>>): Promise<void>;
    protected saveColumnPreferences(newColumns: TableColumnState[]): void;
    protected setColumnsAndSave: (columns: Array<TableColumnInternal<T>>) => Promise<void>;
    protected addTagColumn: () => void;
    protected setTagTableColumnHeader(state: {
        tagKeys: string[];
        selectedTagColumnKeys: string[];
    }, column: TableColumnInternal<T>): void;
    protected configureTagColumn: (column: TableColumnInternal<T>, tagKey: string) => void;
    protected onSort: (sort: TableSortOptions<T>) => void;
    render(): React.JSX.Element;
}
export { TableBaseColumn, TableRow, TableSortOptions, TableSortFunction, Pagination, CheckedState, };
