import { __assign, __awaiter, __generator, __makeTemplateObject } from "tslib";
import * as React from 'react';
import styled from 'styled-components';
import * as uuid from 'uuid';
import find from 'lodash/find';
import startsWith from 'lodash/startsWith';
import isEmpty from 'lodash/isEmpty';
import { Alert as AlertBase } from '../Alert';
import { Txt } from '../Txt';
import { Input } from '../Input';
import { Button } from '../Button';
import { SimpleConfirmationModal, } from '../../internal/SimpleConfirmationModal';
import { withPreventDefault, stopKeyDownEvent } from '../../utils';
import { useTranslation } from '../../hooks/useTranslation';
var Alert = styled(AlertBase)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tpadding: 8px 0 18px;\n"], ["\n\tpadding: 8px 0 18px;\n"])));
var NewTagTr = styled.tr(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\ttable > thead > & > td {\n\t\tpadding-top: 0;\n\t\tpadding-bottom: 0;\n\t}\n"], ["\n\ttable > thead > & > td {\n\t\tpadding-top: 0;\n\t\tpadding-bottom: 0;\n\t}\n"])));
var NewTagErrorsTr = styled.tr(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n\ttable > thead > & > td {\n\t\theight: 30px;\n\t\tpadding-top: 5px;\n\t\tpadding-bottom: 5px;\n\t}\n"], ["\n\ttable > thead > & > td {\n\t\theight: 30px;\n\t\tpadding-top: 5px;\n\t\tpadding-bottom: 5px;\n\t}\n"])));
var RESERVED_NAMESPACE = 'io.resin.';
var newTagValidationRules = function (t, key, existingTags) {
    return [
        {
            test: function () { return !key || isEmpty(key); },
            message: t('fields_errors.tag_name_cannot_be_empty'),
        },
        {
            test: function () { return /\s/.test(key); },
            message: t('fields_errors.tag_names_cannot_contain_whitespace'),
        },
        {
            test: function () { return startsWith(key, RESERVED_NAMESPACE); },
            message: t("fields_errors.some_tag_keys_are_reserved", {
                namespace: RESERVED_NAMESPACE,
            }),
        },
        {
            test: function () {
                return existingTags.some(function (tag) { return tag.state !== 'deleted' && tag.tag_key === key; });
            },
            message: t('fields_errors.tag_with_same_name_exists'),
        },
    ];
};
export var AddTagForm = function (_a) {
    var itemType = _a.itemType, existingTags = _a.existingTags, overwritableTags = _a.overwritableTags, addTag = _a.addTag;
    var t = useTranslation().t;
    var _b = React.useState(''), tagKey = _b[0], setTagKey = _b[1];
    var _c = React.useState(''), value = _c[0], setValue = _c[1];
    var _d = React.useState(false), tagKeyIsInvalid = _d[0], setTagKeyIsInvalid = _d[1];
    var _e = React.useState(), error = _e[0], setError = _e[1];
    var _f = React.useState(false), canSubmit = _f[0], setCanSubmit = _f[1];
    var _g = React.useState(), confirmationModalOptions = _g[0], setConfirmationModalOptions = _g[1];
    var tagKeyInput = React.useRef(null);
    var valueInput = React.useRef(null);
    var formUuid = "add-tag-form-".concat(uuid.v1());
    var checkNewTagValidity = function (key) {
        var failedRule = newTagValidationRules(t, key, existingTags).find(function (rule) { return rule.test(); });
        var hasErrors = !!failedRule;
        setTagKeyIsInvalid(hasErrors);
        setError(failedRule);
        setCanSubmit(!hasErrors);
        return hasErrors;
    };
    var checkTagOverwrites = function () { return __awaiter(void 0, void 0, void 0, function () {
        var overwritableTag, count, result;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    overwritableTag = find(overwritableTags || [], {
                        tag_key: tagKey,
                    });
                    if (!overwritableTag) {
                        return [2, true];
                    }
                    count = overwritableTag.items.length;
                    return [4, new Promise(function (resolve) {
                            var confirmationModalOptions = {
                                title: t('warnings.this_would_overwrite_tags', {
                                    itemType: itemType,
                                    count: count,
                                }),
                                children: (React.createElement(Txt, null,
                                    t("warnings.tag_name_group_exists_and_will_be_overwritten", {
                                        itemType: itemType,
                                        count: count,
                                    }),
                                    React.createElement("br", null),
                                    t('actions_confirmations.confirm_to_proceed'))),
                                action: t('actions.continue'),
                                onClose: resolve,
                            };
                            setConfirmationModalOptions(confirmationModalOptions);
                        })];
                case 1:
                    result = _a.sent();
                    setConfirmationModalOptions(undefined);
                    return [2, result];
            }
        });
    }); };
    var internalAddTag = withPreventDefault(function () {
        if (checkNewTagValidity(tagKey)) {
            return;
        }
        return checkTagOverwrites().then(function (confirmed) {
            if (!confirmed) {
                return;
            }
            addTag({
                tag_key: tagKey,
                value: value,
            });
            setTagKey('');
            setValue('');
            setTagKeyIsInvalid(false);
            setError(undefined);
            setCanSubmit(false);
            if (tagKeyInput && tagKeyInput.current) {
                tagKeyInput.current.blur();
            }
            if (valueInput && valueInput.current) {
                valueInput.current.blur();
            }
        });
    });
    return (React.createElement("thead", null,
        React.createElement(NewTagTr, { onKeyDown: function (e) { return stopKeyDownEvent(e, 13, internalAddTag); } },
            React.createElement("td", null),
            React.createElement("td", null,
                React.createElement(Input, { form: formUuid, width: "100%", ref: tagKeyInput, onChange: function (e) {
                        setTagKey(e.target.value);
                        checkNewTagValidity(e.target.value);
                    }, value: tagKey, invalid: tagKeyIsInvalid, placeholder: t('labels.tag_name') })),
            React.createElement("td", null,
                React.createElement(Input, { form: formUuid, width: "100%", ref: valueInput, onChange: function (e) { return setValue(e.target.value); }, value: value, placeholder: t('labels.value') })),
            React.createElement("td", null,
                React.createElement("form", { id: formUuid, onSubmit: internalAddTag },
                    React.createElement(Button, { width: "120px", tertiary: true, onClick: internalAddTag, disabled: !canSubmit }, t('actions.add_tag'))),
                confirmationModalOptions && (React.createElement(SimpleConfirmationModal, __assign({}, confirmationModalOptions))))),
        React.createElement(NewTagErrorsTr, null,
            React.createElement("td", null),
            React.createElement("td", { colSpan: 2 }, error && (React.createElement(Alert, { danger: true, plaintext: true }, error.message))),
            React.createElement("td", null))));
};
var templateObject_1, templateObject_2, templateObject_3;
