import { __assign } from "tslib";
import React from 'react';
import { TagManagementModal } from '.';
import { mount } from 'enzyme';
import { Button } from '../Button';
import { Provider } from '../Provider';
import { Input } from '../Input';
import { SimpleConfirmationModal } from '../../internal/SimpleConfirmationModal';
import { useTranslation } from '../../hooks/useTranslation';
export var itemsExample = [
    {
        id: 1,
        name: 'item-with-tag-1',
        tag_field: [
            {
                tag_key: 'tag1-key',
                value: 'tag-value',
            },
            {
                tag_key: 'tag2-key',
                value: 'tag3-value',
            },
            {
                tag_key: 'tag3-key',
                value: 'tag3-value',
            },
        ],
    },
    {
        id: 2,
        name: 'item-with-tag-2',
        tag_field: [
            {
                tag_key: 'tag1-key',
                value: 'tag-value',
            },
            {
                tag_key: 'tag2-key',
                value: 'tag3-value',
            },
        ],
    },
];
var TagManagement = function () {
    var _a = React.useState(false), isModalOpen = _a[0], setIsModalOpen = _a[1];
    var t = useTranslation().t;
    return (React.createElement(React.Fragment, null,
        React.createElement(Button, { onClick: function () { return setIsModalOpen(true); }, primary: true }, t('labels.tags')),
        isModalOpen && (React.createElement(TagManagementModal, __assign({}, props, { cancel: function () { return setIsModalOpen(false); }, done: function () { return setIsModalOpen(false); } })))));
};
var props = {
    items: itemsExample,
    itemType: 'tag',
    titleField: 'name',
    tagField: 'tag_field',
};
describe('TagManagement component', function () {
    it('Should render the TagManagement component', function () {
        var component = mount(React.createElement(Provider, null,
            React.createElement(TagManagement, null)));
        var button = component.findWhere(function (node) { return node.is(Button) && typeof node.prop('children') === 'string'; });
        expect(button.text()).toEqual('Tags');
    });
    it('Should render the TagManagement modal component', function () {
        var component = mount(React.createElement(Provider, null,
            React.createElement(TagManagement, null)));
        var button = component.findWhere(function (node) { return node.is(Button) && typeof node.prop('children') === 'string'; });
        button.simulate('click');
        var modal = component.find(TagManagementModal);
        expect(modal).toHaveLength(1);
    });
    it('Should render the TagManagement overwrite alert modal component', function () {
        var component = mount(React.createElement(Provider, null,
            React.createElement(TagManagement, null)));
        var button = component.findWhere(function (node) { return node.is(Button) && typeof node.prop('children') === 'string'; });
        button.simulate('click');
        var modal = component.find(TagManagementModal);
        var keyInput = modal.find(Input).first();
        var valueInput = modal.find(Input).last();
        keyInput
            .find('input')
            .simulate('change', { target: { value: 'tag3-key' } });
        valueInput
            .find('input')
            .simulate('change', { target: { value: 'running-test' } });
        var addTagButton = modal.findWhere(function (node) { return node.is(Button) && node.text() === 'Add tag'; });
        addTagButton.simulate('click');
        var alertModal = component.find(SimpleConfirmationModal);
        expect(alertModal.find('h3').text()).toBe('Adding this would overwrite tags on tag');
    });
    it('Should disable Add tag button if tag key is empty', function () {
        var component = mount(React.createElement(Provider, null,
            React.createElement(TagManagement, null)));
        var button = component.findWhere(function (node) { return node.is(Button) && typeof node.prop('children') === 'string'; });
        button.simulate('click');
        var modal = component.find(TagManagementModal);
        var addTagButton = modal.findWhere(function (node) { return node.is(Button) && node.text() === 'Add tag'; });
        expect(addTagButton.prop('disabled')).toBe(true);
    });
});
