import { __awaiter, __generator, __spreadArray } from "tslib";
import * as React from 'react';
import { createPoll } from '../utils/poll';
export var useRequest = function (action, deps, options) {
    var _a, _b, _c;
    var polling = options.polling, pollInterval = options.pollInterval, stopExecution = options.stopExecution;
    var _d = React.useState(true), loading = _d[0], setLoading = _d[1];
    var _e = React.useState(), error = _e[0], setError = _e[1];
    var _f = React.useState(), data = _f[0], setData = _f[1];
    var _g = React.useState(true), isVisible = _g[0], setIsVisible = _g[1];
    var pollRef = React.useRef();
    var loadDataDeps = 'persist' in deps || 'reset' in deps
        ? __spreadArray(__spreadArray([], ((_a = deps.persist) !== null && _a !== void 0 ? _a : []), true), ((_b = deps.reset) !== null && _b !== void 0 ? _b : []), true) : deps;
    React.useEffect(function () {
        var handleVisibilityChange = function () { return setIsVisible(!document.hidden); };
        document.addEventListener('visibilitychange', handleVisibilityChange);
        return function () {
            return document.removeEventListener('visibilitychange', handleVisibilityChange);
        };
    });
    var loadData = React.useCallback(function (poll) { return __awaiter(void 0, void 0, void 0, function () {
        var response, e_1;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    _a.trys.push([0, 2, 3, 4]);
                    return [4, action(poll)];
                case 1:
                    response = _a.sent();
                    setData(response);
                    return [3, 4];
                case 2:
                    e_1 = _a.sent();
                    if (e_1 instanceof Error) {
                        setError(e_1);
                    }
                    else {
                        setError(new Error(typeof e_1 === 'string' ? e_1 : 'Unknown error'));
                    }
                    setData([]);
                    return [3, 4];
                case 3:
                    setLoading(false);
                    return [7];
                case 4: return [2];
            }
        });
    }); }, loadDataDeps);
    var forcePoll = React.useCallback(function () {
        setLoading(true);
        if (pollRef.current) {
            pollRef.current.poll({ forced: true });
        }
        else {
            loadData();
        }
    }, [pollRef, loadData]);
    React.useEffect(function () {
        if (stopExecution) {
            return pollRef.current && pollRef.current.stop();
        }
        if (!polling) {
            loadData();
            return;
        }
        pollRef.current = createPoll(loadData, pollInterval, isVisible);
        pollRef.current.start();
        return function () {
            if (pollRef.current) {
                pollRef.current.destroy();
                pollRef.current = undefined;
            }
        };
    }, [polling, loadData, pollInterval, stopExecution, isVisible]);
    React.useEffect(function () {
        if (!polling) {
            return;
        }
        setData(undefined);
    }, __spreadArray(__spreadArray([], ('reset' in deps ? (_c = deps.reset) !== null && _c !== void 0 ? _c : [] : deps), true), [
        polling,
    ], false));
    React.useEffect(function () {
        if (!polling) {
            return;
        }
        forcePoll();
    }, loadDataDeps);
    var result = [data, loading, error, forcePoll];
    result.data = data;
    result.isLoading = loading;
    result.error = error;
    result.forcePoll = forcePoll;
    return result;
};
