import { __spreadArray } from "tslib";
import * as React from 'react';
import { Flex } from '../../components/Flex';
import { Box } from '../../components/Box';
import { Txt } from '../../components/Txt';
import { Tabs, Tab } from '../../components/Tabs';
import { Link } from '../../components/Link';
import { List } from '../../components/List';
import { Heading } from '../../components/Heading';
import { useTranslation } from '../../hooks/useTranslation';
import { interpolateMustache } from './utils';
export var getUserOs = function () {
    var platform = window.navigator.platform.toLowerCase();
    if (platform.includes('win')) {
        return 'Windows';
    }
    if (platform.includes('mac')) {
        return 'MacOS';
    }
    if (platform.includes('x11') || platform.includes('linux')) {
        return 'Linux';
    }
    return 'Unknown';
};
var dtJsonTocontractOsKeyMap = {
    windows: 'Windows',
    osx: 'MacOS',
    linux: 'Linux',
};
export var ApplicationInstructions = React.memo(function (_a) {
    var _b, _c, _d;
    var deviceType = _a.deviceType, templateData = _a.templateData;
    var t = useTranslation().t;
    var _e = React.useState(getUserOs()), currentOs = _e[0], setCurrentOs = _e[1];
    var instructions = React.useMemo(function () {
        if ((deviceType === null || deviceType === void 0 ? void 0 : deviceType.instructions) == null ||
            Array.isArray(deviceType.instructions) ||
            typeof deviceType.instructions !== 'object') {
            return deviceType === null || deviceType === void 0 ? void 0 : deviceType.instructions;
        }
        var instructionsByOs = deviceType.instructions;
        return Object.fromEntries(Object.entries(instructionsByOs).map(function (_a) {
            var key = _a[0], value = _a[1];
            var normalizedKey = key in dtJsonTocontractOsKeyMap
                ? dtJsonTocontractOsKeyMap[key]
                : key;
            return [normalizedKey, value];
        }));
    }, [deviceType === null || deviceType === void 0 ? void 0 : deviceType.instructions]);
    var hasOsSpecificInstructions = instructions != null &&
        !Array.isArray(instructions) &&
        typeof instructions === 'object';
    var normalizedOs = currentOs === 'Unknown' ? 'Linux' : currentOs;
    React.useEffect(function () {
        if (hasOsSpecificInstructions) {
            var oses = Object.keys(instructions);
            if (!oses.includes(currentOs) && oses.length > 0) {
                setCurrentOs(oses[0]);
            }
        }
    }, [currentOs, setCurrentOs, instructions, hasOsSpecificInstructions]);
    if (!deviceType || !instructions) {
        return React.createElement(Txt, null, t('no_data.no_instructions_found'));
    }
    var interpolatedInstructions = (_b = (hasOsSpecificInstructions
        ? instructions[normalizedOs]
        : instructions)) === null || _b === void 0 ? void 0 : _b.map(function (instruction) {
        return interpolateMustache(templateData, instruction.replace(/<a/, '<a target="_blank"'));
    });
    var hasConfigDownloadOnly = ((_c = deviceType.yocto) === null || _c === void 0 ? void 0 : _c.deployArtifact) === 'docker-image';
    var finalInstructions = interpolatedInstructions
        ? __spreadArray(__spreadArray([
            hasConfigDownloadOnly
                ? t('actions.use_form_to_download_configuration')
                : t('actions.use_from_to_configure_and_download')
        ], interpolatedInstructions, true), [
            t('actions_messages.appearance_device_explanation'),
        ], false) : null;
    return (React.createElement(Flex, { flexDirection: "column", alignItems: "flex-start" },
        React.createElement(Heading.h5, { mb: 3 }, t('labels.instructions')),
        hasOsSpecificInstructions && (React.createElement(Box, { mb: 3 },
            React.createElement(Tabs, { activeIndex: (_d = Object.keys(instructions).indexOf(currentOs)) !== null && _d !== void 0 ? _d : 0, onActive: function (index) {
                    var _a;
                    return setCurrentOs((_a = Object.keys(instructions)[index]) !== null && _a !== void 0 ? _a : 'Unknown');
                } }, Object.keys(instructions).map(function (os) {
                return React.createElement(Tab, { key: os, title: os });
            })))),
        finalInstructions != null && (React.createElement(InstructionsList, { instructions: finalInstructions })),
        React.createElement(Flex, { mt: 4 },
            React.createElement(Txt, null,
                "For more details please refer to our",
                ' ',
                React.createElement(Link, { blank: true, href: "https://www.balena.io/docs/learn/getting-started/".concat(deviceType.slug, "/nodejs/") }, "Getting Started Guide"),
                "."))));
});
var InstructionsItem = function (_a) {
    var node = _a.node;
    return React.createElement("span", { dangerouslySetInnerHTML: { __html: node } });
};
var InstructionsList = function (_a) {
    var instructions = _a.instructions;
    return (React.createElement(List, { ordered: true, fontSize: 14 }, instructions.map(function (item, i) {
        return React.createElement(InstructionsItem, { key: "".concat(item, "_").concat(i), node: item });
    })));
};
