import { __assign, __awaiter, __generator, __makeTemplateObject, __rest } from "tslib";
import { faTimes } from '@fortawesome/free-solid-svg-icons/faTimes';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import * as React from 'react';
import styled from 'styled-components';
import { ApplicationInstructions } from './ApplicationInstructions';
import { ImageForm } from './ImageForm';
import isEmpty from 'lodash/isEmpty';
import noop from 'lodash/noop';
import uniq from 'lodash/uniq';
import { OsTypesEnum, } from './models';
import { Box } from '../../components/Box';
import { Flex } from '../../components/Flex';
import { Txt } from '../../components/Txt';
import { Button } from '../../components/Button';
import { Spinner } from '../../components/Spinner';
import { Alert } from '../../components/Alert';
import { Modal } from '../../components/Modal';
import { Img } from '../../components/Img';
import { useTranslation } from '../../hooks/useTranslation';
import { FALLBACK_LOGO_UNKNOWN_DEVICE, stripVersionBuild } from './utils';
import { OsConfiguration } from './OsConfiguration';
export var DeviceLogo = styled(Img)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\t// To prevent Save Image dialog\n\tpointer-events: none;\n\tdisplay: inline-block;\n\theight: 100%;\n\t// required so that icons in long cells show in the Table in FF\n\tmin-width: 16px;\n\tmax-height: ", ";\n\tmax-width: 100%;\n\tvertical-align: middle;\n\n\t&.device-logo--disabled {\n\t\topacity: 0.4;\n\t}\n"], ["\n\t// To prevent Save Image dialog\n\tpointer-events: none;\n\tdisplay: inline-block;\n\theight: 100%;\n\t// required so that icons in long cells show in the Table in FF\n\tmin-width: 16px;\n\tmax-height: ", ";\n\tmax-width: 100%;\n\tvertical-align: middle;\n\n\t&.device-logo--disabled {\n\t\topacity: 0.4;\n\t}\n"])), function (props) { return (props.small ? '16px' : '24px'); });
var FooterlessModal = styled(Modal)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\t& > div > div:last-child {\n\t\tdisplay: none;\n\t}\n"], ["\n\t& > div > div:last-child {\n\t\tdisplay: none;\n\t}\n"])));
var getUniqueOsTypes = function (osVersions, deviceTypeSlug) {
    if (isEmpty(osVersions) ||
        !deviceTypeSlug ||
        isEmpty(osVersions[deviceTypeSlug])) {
        return [];
    }
    return uniq(osVersions[deviceTypeSlug].map(function (x) { return x.osType; }));
};
export var UnstableTempDownloadImageModal = function (_a) {
    var _b;
    var _c, _d, _e, _f;
    var downloadUrl = _a.downloadUrl, application = _a.application, releaseId = _a.releaseId, compatibleDeviceTypes = _a.compatibleDeviceTypes, initialDeviceType = _a.initialDeviceType, initialOsVersions = _a.initialOsVersions, isInitialDefault = _a.isInitialDefault, onDownloadStart = _a.onDownloadStart, getSupportedOsVersions = _a.getSupportedOsVersions, getSupportedOsTypes = _a.getSupportedOsTypes, getDockerArtifact = _a.getDockerArtifact, hasEsrVersions = _a.hasEsrVersions, downloadConfig = _a.downloadConfig, getDownloadSize = _a.getDownloadSize, onClose = _a.onClose, modalActions = _a.modalActions, authToken = _a.authToken, docsIcon = _a.docsIcon, onFieldChange = _a.onFieldChange;
    var t = useTranslation().t;
    var _g = React.useState(initialDeviceType), deviceType = _g[0], setDeviceType = _g[1];
    var _h = React.useState(null), rawVersion = _h[0], setRawVersion = _h[1];
    var _j = React.useState(false), developmentMode = _j[0], setDevelopmentMode = _j[1];
    var _k = React.useState(initialOsVersions !== null && initialOsVersions !== void 0 ? initialOsVersions : {}), osVersions = _k[0], setOsVersions = _k[1];
    var _l = React.useState(), osType = _l[0], setOsType = _l[1];
    var _m = React.useState(getUniqueOsTypes(osVersions, deviceType === null || deviceType === void 0 ? void 0 : deviceType.slug)), osTypes = _m[0], setOsTypes = _m[1];
    var _o = React.useState((deviceType === null || deviceType === void 0 ? void 0 : deviceType.slug)
        ? (_b = {}, _b[deviceType.slug] = osTypes.includes(OsTypesEnum.ESR), _b) : {}), deviceTypeHasEsr = _o[0], setDeviceTypeHasEsr = _o[1];
    var _p = React.useState(false), isDownloadingConfig = _p[0], setIsDownloadingConfig = _p[1];
    var _q = React.useState(isEmpty(osVersions)), isFetching = _q[0], setIsFetching = _q[1];
    var logoSrc = (_d = (_c = deviceType === null || deviceType === void 0 ? void 0 : deviceType.logo) !== null && _c !== void 0 ? _c : deviceType === null || deviceType === void 0 ? void 0 : deviceType.logoUrl) !== null && _d !== void 0 ? _d : FALLBACK_LOGO_UNKNOWN_DEVICE;
    var defaultDisplayName = (_e = deviceType === null || deviceType === void 0 ? void 0 : deviceType.name) !== null && _e !== void 0 ? _e : '-';
    React.useEffect(function () {
        if (!compatibleDeviceTypes || !hasEsrVersions) {
            return;
        }
        hasEsrVersions(compatibleDeviceTypes.map(function (dt) { return dt.slug; })).then(setDeviceTypeHasEsr);
    }, [compatibleDeviceTypes]);
    React.useEffect(function () {
        if (!deviceType) {
            return;
        }
        var osTypes = getUniqueOsTypes(osVersions, deviceType.slug);
        if (!osTypes.length) {
            return;
        }
        if (!!osType) {
            if (!osTypes.includes(osType)) {
                setOsType(osTypes[0]);
            }
        }
        else {
            setOsType(osTypes.includes(OsTypesEnum.ESR) ? OsTypesEnum.ESR : osTypes[0]);
        }
    }, [deviceType === null || deviceType === void 0 ? void 0 : deviceType.slug, osType, osVersions]);
    React.useEffect(function () {
        if (!compatibleDeviceTypes || !getSupportedOsVersions) {
            return;
        }
        getSupportedOsVersions()
            .then(setOsVersions)
            .catch(function (e) {
            console.error(e);
        })
            .finally(function () { return setIsFetching(false); });
    }, [compatibleDeviceTypes, application]);
    React.useEffect(function () {
        if (!deviceType || !getSupportedOsTypes) {
            return;
        }
        getSupportedOsTypes(application.id, deviceType === null || deviceType === void 0 ? void 0 : deviceType.slug).then(setOsTypes);
    }, [deviceType === null || deviceType === void 0 ? void 0 : deviceType.slug, application.id]);
    if (!deviceType) {
        return null;
    }
    return (React.createElement(FooterlessModal, { width: 1400, title: React.createElement(Flex, { style: { height: 32 }, alignItems: "center" },
            React.createElement(DeviceLogo, { small: false, src: logoSrc, title: defaultDisplayName }),
            React.createElement(Txt.span, { ml: 3 }, t('actions.add_new_device')),
            React.createElement(Button, { ml: "auto", icon: React.createElement(FontAwesomeIcon, { icon: faTimes }), plain: true, onClick: onClose })), cancel: onClose, done: noop },
        React.createElement(Flex, { flexDirection: ['column', 'column', 'column', 'row'] },
            React.createElement(Box, { flex: 2, mr: [0, 0, 0, 3] },
                React.createElement(Spinner, { show: isDownloadingConfig, label: t('loading.generating_configuration_file') },
                    React.createElement(Spinner, { show: isFetching, label: t('loading.fetching_versions') }),
                    !isFetching && (React.createElement(React.Fragment, null,
                        isEmpty(osVersions) && (React.createElement(Alert, { plaintext: true, warning: true }, t('no_data.no_os_versions_available_for_download'))),
                        !!osType && !!compatibleDeviceTypes && (React.createElement(ImageForm, __assign({ onFieldChange: onFieldChange, onDownloadStart: onDownloadStart, setIsDownloadingConfig: setIsDownloadingConfig, deviceType: deviceType, appId: application.id, releaseId: releaseId, downloadUrl: downloadUrl, rawVersion: rawVersion, developmentMode: developmentMode, modalActions: modalActions, authToken: authToken }, (downloadConfig && {
                            downloadConfig: function (_a) {
                                var appId = _a.appId, releaseId = _a.releaseId, _deviceTypeSlug = _a.deviceType, version = _a.version, model = __rest(_a, ["appId", "releaseId", "deviceType", "version"]);
                                return downloadConfig(deviceType, version, model);
                            },
                        }), (getDownloadSize && {
                            getDownloadSize: function () { return __awaiter(void 0, void 0, void 0, function () { return __generator(this, function (_a) {
                                return [2, getDownloadSize(deviceType, rawVersion)];
                            }); }); },
                        }), { configurationComponent: React.createElement(OsConfiguration, { compatibleDeviceTypes: compatibleDeviceTypes, selectedDeviceType: deviceType, selectedOsType: osType, deviceTypeOsVersions: osVersions, osTypes: osTypes, isInitialDefault: isInitialDefault, onSelectedDeviceTypeChange: setDeviceType, onSelectedVersionChange: setRawVersion, onSelectedDevelopmentMode: setDevelopmentMode, onSelectedOsTypeChange: setOsType, hasEsrVersions: (_f = deviceTypeHasEsr[deviceType.slug]) !== null && _f !== void 0 ? _f : false, docsIcon: docsIcon }) }))))))),
            React.createElement(Box, { flex: 1, ml: [0, 0, 0, 3], mt: [3, 0, 0, 0] },
                React.createElement(ApplicationInstructions, { deviceType: deviceType, templateData: {
                        dockerImage: rawVersion
                            ? getDockerArtifact(deviceType.slug, stripVersionBuild(rawVersion))
                            : '',
                    } })))));
};
var templateObject_1, templateObject_2;
