import { __assign, __makeTemplateObject } from "tslib";
import * as React from 'react';
import styled from 'styled-components';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faExclamationTriangle } from '@fortawesome/free-solid-svg-icons/faExclamationTriangle';
import { faFileAlt } from '@fortawesome/free-regular-svg-icons/faFileAlt';
import { Alert } from '../../components/Alert';
import { Badge } from '../../components/Badge';
import { Box } from '../../components/Box';
import { Checkbox } from '../../components/Checkbox';
import { Flex } from '../../components/Flex';
import { Link } from '../../components/Link';
import { Select } from '../../components/Select';
import { RadioButton } from '../../components/RadioButton';
import { Txt } from '../../components/Txt';
import { QuestionMark } from './QuestionMark';
import { DeviceTypeSelector } from './DeviceTypeSelector';
import { OsTypeSelector } from './OsTypeSelector';
import { getPreferredVersionOpts, transformVersions, } from './versions';
import { useTranslation } from '../../hooks/useTranslation';
import { getOsVariantDisplayText } from './utils';
import { useTheme } from '../../hooks/useTheme';
export var DownloadImageLabel = styled.label(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tdisplay: flex;\n\tflex-direction: row;\n\talign-items: center;\n\theight: 21px;\n\tfont-size: 12px;\n\tmargin-bottom: 8px;\n\tfont-weight: normal;\n"], ["\n\tdisplay: flex;\n\tflex-direction: row;\n\talign-items: center;\n\theight: 21px;\n\tfont-size: 12px;\n\tmargin-bottom: 8px;\n\tfont-weight: normal;\n"])));
export var lineColors = {
    next: 1,
    current: 0,
    sunset: 12,
    outdated: 5,
};
var BuildVariants = ['dev', 'prod'];
var getCategorizedVersions = function (deviceTypeOsVersions, deviceType, osType) {
    var _a;
    var osVersions = (_a = deviceTypeOsVersions[deviceType.slug]) !== null && _a !== void 0 ? _a : [];
    var deviceOsVersions = osType
        ? osVersions.filter(function (osVersion) { return osVersion.osType === osType; })
        : osVersions;
    var selectionOpts = transformVersions(deviceOsVersions);
    var preferredSelectionOpts = getPreferredVersionOpts(selectionOpts);
    return {
        selectionOpts: selectionOpts,
        preferredSelectionOpts: preferredSelectionOpts,
    };
};
var VariantSelector = function (_a) {
    var version = _a.version, variant = _a.variant, onVariantChange = _a.onVariantChange, t = _a.t;
    var _b = BuildVariants.map(function (vrnt) {
        var label = React.createElement(Txt.span, { bold: true }, getOsVariantDisplayText(vrnt));
        if (vrnt === 'dev') {
            label = (React.createElement(React.Fragment, null,
                label,
                React.createElement(Alert, { ml: 3, info: true, plaintext: true }, t('info.recommended_for_new_users'))));
        }
        return {
            label: label,
            disabled: version == null ||
                (version.hasPrebuiltVariants && !version.rawVersions[vrnt]),
            checked: vrnt === variant,
            onChange: function () { return onVariantChange(vrnt); },
        };
    }), devOpts = _b[0], prodOpts = _b[1];
    return (React.createElement(React.Fragment, null,
        React.createElement(RadioButton, __assign({}, devOpts)),
        React.createElement(Txt.p, { fontSize: 1, mt: 1, mb: 3, color: "tertiary.main" },
            t('info.development_images_for_local_development_1'),
            ' ',
            React.createElement(Link, { href: "https://balena.io/docs/development/local-mode/", blank: true }, t('info.development_images_for_local_development_2')),
            ' ',
            t('info.development_images_for_local_development_3'),
            ' ',
            React.createElement("strong", null, t('info.development_images_for_local_development_4'))),
        React.createElement(RadioButton, __assign({}, prodOpts)),
        React.createElement(Txt.p, { fontSize: 1, mt: 1, color: "tertiary.main" }, t('info.production_images_not_for_local_development'))));
};
var VersionSelectOption = function (_a) {
    var _b, _c;
    var t = _a.t, option = _a.option, theme = _a.theme;
    return (React.createElement(Flex, { alignItems: "center", py: 2, pl: 3, tooltip: (_b = option.knownIssueList) !== null && _b !== void 0 ? _b : undefined, maxWidth: "445px" },
        React.createElement(Txt, { mr: 2 }, option.title),
        ' ',
        !!option.line && (React.createElement(Badge, { ml: 1, shade: (_c = lineColors[option.line]) !== null && _c !== void 0 ? _c : 0 }, option.line)),
        !!option.isRecommended && (React.createElement(Badge, { ml: 1, shade: 20 }, t('labels.recommended'))),
        !!option.knownIssueList && (React.createElement(Box, { ml: 2, tooltip: option.knownIssueList, display: "contents", style: { lineHeight: 'normal' } },
            React.createElement(FontAwesomeIcon, { color: theme.colors.warning.main, icon: faExclamationTriangle }),
            React.createElement(Txt, { ml: 1, truncate: true }, option.knownIssueList)))));
};
export var OsConfiguration = function (_a) {
    var deviceTypeOsVersions = _a.deviceTypeOsVersions, compatibleDeviceTypes = _a.compatibleDeviceTypes, selectedDeviceType = _a.selectedDeviceType, osTypes = _a.osTypes, hasEsrVersions = _a.hasEsrVersions, selectedOsType = _a.selectedOsType, isInitialDefault = _a.isInitialDefault, onSelectedVersionChange = _a.onSelectedVersionChange, onSelectedDevelopmentMode = _a.onSelectedDevelopmentMode, onSelectedDeviceTypeChange = _a.onSelectedDeviceTypeChange, onSelectedOsTypeChange = _a.onSelectedOsTypeChange, docsIcon = _a.docsIcon;
    var theme = useTheme();
    var t = useTranslation().t;
    var _b = React.useState(false), showAllVersions = _b[0], setShowAllVersions = _b[1];
    var _c = React.useState(), version = _c[0], setVersion = _c[1];
    var _d = React.useState('prod'), variant = _d[0], setVariant = _d[1];
    var _e = getCategorizedVersions(deviceTypeOsVersions, selectedDeviceType, selectedOsType), selectionOpts = _e.selectionOpts, preferredSelectionOpts = _e.preferredSelectionOpts;
    var versionSelectionOpts = showAllVersions
        ? selectionOpts
        : preferredSelectionOpts;
    var showAllVersionsToggle = preferredSelectionOpts.length < selectionOpts.length;
    React.useEffect(function () {
        if (!version) {
            return;
        }
        var versionWithVariant = version.hasPrebuiltVariants
            ? version.rawVersions[variant]
            : version.rawVersion;
        if (versionWithVariant) {
            onSelectedVersionChange(versionWithVariant);
            onSelectedDevelopmentMode(variant === 'dev');
        }
        if (version.hasPrebuiltVariants && !version.rawVersions[variant]) {
            setVariant(variant === 'dev' ? 'prod' : 'dev');
        }
    }, [version, variant]);
    var handleShowAllVersions = function (e) {
        var _a;
        var isChecked = e.target.checked;
        setShowAllVersions(isChecked);
        if (isChecked || !version) {
            return;
        }
        var selectedValueIsPreferred = preferredSelectionOpts.some(function (ver) { return ver.value === version.value; });
        if (selectedValueIsPreferred) {
            return;
        }
        var preferred = (_a = preferredSelectionOpts.find(function (ver) { return ver.isRecommended; })) !== null && _a !== void 0 ? _a : preferredSelectionOpts === null || preferredSelectionOpts === void 0 ? void 0 : preferredSelectionOpts[0];
        if (preferred) {
            setVersion(preferred);
        }
    };
    var handleSelectedDeviceTypeChange = React.useCallback(function (dt) {
        if ((selectedDeviceType === null || selectedDeviceType === void 0 ? void 0 : selectedDeviceType.slug) === dt.slug) {
            return;
        }
        var newDeviceType = compatibleDeviceTypes === null || compatibleDeviceTypes === void 0 ? void 0 : compatibleDeviceTypes.find(function (cdt) { return cdt.slug === dt.slug; });
        if (!newDeviceType) {
            return;
        }
        onSelectedDeviceTypeChange(newDeviceType);
    }, [compatibleDeviceTypes, selectedDeviceType]);
    React.useEffect(function () {
        var _a;
        setVersion((_a = versionSelectionOpts.find(function (ver) { return ver.isRecommended; })) !== null && _a !== void 0 ? _a : versionSelectionOpts[0]);
    }, [selectedDeviceType, selectedOsType]);
    return (React.createElement(React.Fragment, null,
        React.createElement(Flex, { mb: 3, mx: -2 },
            compatibleDeviceTypes.length > 1 && (React.createElement(Box, { flex: 3, mx: 2 },
                React.createElement(DownloadImageLabel, null,
                    t('placeholders.select_device_type'),
                    React.createElement(QuestionMark, { tooltip: t('info.applications_support_devices_with_same_architecture') })),
                React.createElement(DeviceTypeSelector, { deviceTypeOptions: compatibleDeviceTypes, selectedDeviceType: selectedDeviceType, selectDeviceTypeOption: handleSelectedDeviceTypeChange }))),
            (!isInitialDefault || !selectedOsType) && hasEsrVersions && (React.createElement(Box, { flex: 2, mx: 2 },
                React.createElement(DownloadImageLabel, null,
                    t('placeholders.select_os_type_status'),
                    ' ',
                    React.createElement(DocsLink, { href: "https://www.balena.io/docs/reference/OS/extended-support-release", docsIcon: docsIcon })),
                React.createElement(OsTypeSelector, { supportedOsTypes: osTypes, hasEsrVersions: hasEsrVersions, selectedOsTypeSlug: selectedOsType, onSelectedOsTypeChange: onSelectedOsTypeChange })))),
        (!isInitialDefault || !version) && (React.createElement(Box, { mb: 3 },
            React.createElement(DownloadImageLabel, null, t('placeholders.select_version')),
            React.createElement(Flex, { alignItems: "center", mx: -2 },
                React.createElement(Box, { flex: 3, mx: 2 },
                    React.createElement(Select, { id: "e2e-download-image-versions-list", valueKey: "value", labelKey: "title", emptySearchMessage: "No version available for this application type", value: version, valueLabel: version && (React.createElement(VersionSelectOption, { t: t, option: version, theme: theme })), placeholder: 'Choose a version...', onChange: function (_a) {
                            var option = _a.option;
                            setVersion(option);
                        }, options: versionSelectionOpts }, function (option) { return (React.createElement(VersionSelectOption, { t: t, option: option, theme: theme })); })),
                showAllVersionsToggle && (React.createElement(Box, { flex: 2, mx: 2 },
                    React.createElement(Checkbox, { checked: showAllVersions, label: 'Show outdated versions', onChange: handleShowAllVersions, className: "e2e-show-outdated-images" })))))),
        (!isInitialDefault || !variant) && (React.createElement(Box, null,
            React.createElement(DownloadImageLabel, null, t('placeholders.select_edition')),
            React.createElement(Box, null,
                React.createElement(VariantSelector, { t: t, version: version, variant: variant, onVariantChange: setVariant }))))));
};
export var DocsLink = function (_a) {
    var href = _a.href, docsIcon = _a.docsIcon;
    return (React.createElement(Link, { blank: true, href: href, fontSize: 2, ml: 2 }, docsIcon ? (React.createElement(FontAwesomeIcon, { icon: docsIcon })) : (React.createElement(FontAwesomeIcon, { icon: faFileAlt }))));
};
var templateObject_1;
