import { __assign, __rest } from "tslib";
import * as React from 'react';
import { Badge } from '../../components/Badge';
import { Flex } from '../../components/Flex';
import { Select } from '../../components/Select';
import { Txt } from '../../components/Txt';
import { useTranslation } from '../../hooks/useTranslation';
import { OsTypesEnum } from './models';
import { getOsTypeName } from './utils';
var OsTypeOption = function (_a) {
    var osType = _a.osType, bold = _a.bold;
    var t = useTranslation().t;
    if (!osType) {
        return React.createElement(Txt.span, null, t('placeholders.select_os_type'));
    }
    return (React.createElement(Flex, { width: "100%", justifyContent: "space-between", alignItems: "center" },
        React.createElement(Txt.span, { bold: bold }, getOsTypeName(osType.slug)),
        React.createElement(Flex, null,
            !osType.supportedForDeviceType && (React.createElement(Badge, { mx: 2, shade: 11 }, t('no_data.no_versions_yet'))),
            !osType.supportedForApp && (React.createElement(Badge, { shade: 6, mx: 2 }, t('info.production_and_enterprise_plan_only'))))));
};
export var OsTypeSelector = function (_a) {
    var supportedOsTypes = _a.supportedOsTypes, hasEsrVersions = _a.hasEsrVersions, selectedOsTypeSlug = _a.selectedOsTypeSlug, onSelectedOsTypeChange = _a.onSelectedOsTypeChange, otherProps = __rest(_a, ["supportedOsTypes", "hasEsrVersions", "selectedOsTypeSlug", "onSelectedOsTypeChange"]);
    var t = useTranslation().t;
    var selectOsTypes = Object.values({
        default: OsTypesEnum.DEFAULT,
        ESR: OsTypesEnum.ESR,
    }).map(function (osType) {
        var supportedForDeviceType = osType === OsTypesEnum.ESR ? hasEsrVersions : true;
        var supportedForApp = supportedOsTypes.includes(osType);
        var disabled = !supportedForApp || !supportedForDeviceType;
        return {
            slug: osType,
            disabled: disabled,
            supportedForDeviceType: supportedForDeviceType,
            supportedForApp: supportedForApp,
        };
    });
    var selectedOsType = selectOsTypes.find(function (osType) {
        return osType.slug === selectedOsTypeSlug && osType.supportedForDeviceType;
    });
    return (React.createElement(Select, __assign({ id: "newAppApplicationType", options: selectOsTypes, valueKey: "slug", disabledKey: "disabled", disabled: supportedOsTypes.length === 0, value: selectedOsType, valueLabel: React.createElement(Flex, { width: "100%", py: 2, pl: 3 },
            React.createElement(OsTypeOption, { osType: selectedOsType })), onChange: function (_a) {
            var option = _a.option;
            return !option.disabled && onSelectedOsTypeChange(option.slug);
        } }, otherProps), function (option) { return (React.createElement(Flex, { tooltip: !option.supportedForDeviceType
            ? t('info.no_esr_versions_are_available_for_device_type')
            : undefined, flexDirection: "column", py: 2, pl: 3 },
        React.createElement(OsTypeOption, { osType: option, bold: selectedOsTypeSlug === option.slug }))); }));
};
